#generated by makeschemedata.py

version="2.24"

scheme_keywords = [
    '&assertion',
    '&condition',
    '&error',
    '&i/o',
    '&i/o-decoding',
    '&i/o-encoding',
    '&i/o-file-already-exists',
    '&i/o-file-does-not-exist',
    '&i/o-file-is-read-only',
    '&i/o-file-protection',
    '&i/o-filename',
    '&i/o-invalid-position',
    '&i/o-port',
    '&i/o-read',
    '&i/o-write',
    '&implementation-restriction',
    '&irritants',
    '&lexical',
    '&message',
    '&no-infinities',
    '&no-nans',
    '&non-continuable',
    '&serious',
    '&syntax',
    '&undefined',
    '&violation',
    '&warning',
    '&who',
    '*',
    '+',
    '-',
    '->char-set',
    '/',
    '1+',
    '1-',
    '<',
    '<=',
    '=',
    '==',
    '>',
    '>=',
    'abandoned-mutex-exception?',
    'abort',
    'abort-to-prompt',
    'abs',
    'absolute-file-name?',
    'access?',
    'acons',
    'acos',
    'acosh',
    'activate-readline',
    'adapt-response-version',
    'add',
    'add-duration',
    'add-duration!',
    'add-ephemeral-stepping-trap!',
    'add-ephemeral-trap-at-frame-finish!',
    'add-fdes-finalizer!',
    'add-hook!',
    'add-method!',
    'add-ref-resolver!',
    'add-to-load-path',
    'add-trace-at-procedure-call!',
    'add-trap!',
    'add-trap-at-procedure-call!',
    'add-trap-at-source-location!',
    'add/immediate',
    'alignof',
    'alist->hash-table',
    'alist->hashq-table',
    'alist->hashv-table',
    'alist->hashx-table',
    'alist->vhash',
    'alist-cons',
    'alist-copy',
    'alist-delete',
    'alist-delete!',
    'all-mapped-elf-images',
    'alloc-frame',
    'allocate-struct',
    'allocate-struct/immediate',
    'allow-legacy-syntax-objects?',
    'and',
    'and-let*',
    'and=>',
    'angle',
    'any',
    'any->c32vector',
    'any->c64vector',
    'any->f32vector',
    'any->f64vector',
    'any->s16vector',
    'any->s32vector',
    'any->s64vector',
    'any->s8vector',
    'any->u16vector',
    'any->u32vector',
    'any->u64vector',
    'any->u8vector',
    'any-bits-set?',
    'append',
    'append!',
    'append-map',
    'append-map!',
    'append-reverse',
    'append-reverse!',
    'apply',
    'apply-non-program',
    'apply-templates',
    'apropos',
    'apropos-completion-function',
    'arithmetic-shift',
    'arity:allow-other-keys?',
    'arity:end',
    'arity:kw',
    'arity:nopt',
    'arity:nreq',
    'arity:rest?',
    'arity:start',
    'array->list',
    'array-cell-ref',
    'array-cell-set!',
    'array-contents',
    'array-copy',
    'array-copy!',
    'array-copy-in-order!',
    'array-dimensions',
    'array-equal?',
    'array-fill!',
    'array-for-each',
    'array-in-bounds?',
    'array-index-map!',
    'array-length',
    'array-map!',
    'array-map-in-order!',
    'array-rank',
    'array-ref',
    'array-set!',
    'array-shape',
    'array-slice',
    'array-slice-for-each',
    'array-slice-for-each-in-order',
    'array-type',
    'array?',
    'ash',
    'asin',
    'asinh',
    'assert',
    'assert-curr-char',
    'assert-nargs-ee',
    'assert-nargs-ee/locals',
    'assert-nargs-ge',
    'assert-nargs-le',
    'assertion-violation',
    'assertion-violation?',
    'assoc',
    'assoc-ref',
    'assoc-remove!',
    'assoc-set!',
    'assp',
    'assq',
    'assq-ref',
    'assq-remove!',
    'assq-set!',
    'assv',
    'assv-ref',
    'assv-remove!',
    'assv-set!',
    'atan',
    'atanh',
    'atomic-box-compare-and-swap!',
    'atomic-box-ref',
    'atomic-box-set!',
    'atomic-box-swap!',
    'atomic-box?',
    'attlist->alist',
    'attlist-add',
    'attlist-fold',
    'attlist-null?',
    'attlist-remove-top',
    'backtrace',
    'basename',
    'begin',
    'binary-port?',
    'bind-kwargs',
    'bind-rest',
    'bind-textdomain-codeset',
    'binding',
    'binding-index',
    'binding-name',
    'binding-ref',
    'binding-representation',
    'binding-set!',
    'binding-slot',
    'binding:boxed?',
    'binding:end',
    'binding:index',
    'binding:name',
    'binding:start',
    'bindtextdomain',
    'bit-count',
    'bit-count*',
    'bit-extract',
    'bit-field',
    'bit-invert!',
    'bit-position',
    'bit-set*!',
    'bit-set?',
    'bitvector',
    'bitvector->list',
    'bitvector-fill!',
    'bitvector-length',
    'bitvector-ref',
    'bitvector-set!',
    'bitvector?',
    'bitwise-and',
    'bitwise-arithmetic-shift',
    'bitwise-arithmetic-shift-left',
    'bitwise-arithmetic-shift-right',
    'bitwise-bit-count',
    'bitwise-bit-field',
    'bitwise-bit-set?',
    'bitwise-copy-bit',
    'bitwise-copy-bit-field',
    'bitwise-first-bit-set',
    'bitwise-if',
    'bitwise-ior',
    'bitwise-length',
    'bitwise-merge',
    'bitwise-not',
    'bitwise-reverse-bit-field',
    'bitwise-rotate-bit-field',
    'bitwise-xor',
    'boolean?',
    'booleans->integer',
    'bound-identifier=?',
    'box',
    'box-ref',
    'box-set!',
    'box?',
    'br',
    'br-if-<',
    'br-if-<=',
    'br-if-=',
    'br-if-char',
    'br-if-eq',
    'br-if-eqv',
    'br-if-f64-<',
    'br-if-f64-<=',
    'br-if-f64-=',
    'br-if-f64->',
    'br-if-f64->=',
    'br-if-logtest',
    'br-if-nargs-gt',
    'br-if-nargs-lt',
    'br-if-nargs-ne',
    'br-if-nil',
    'br-if-npos-gt',
    'br-if-null',
    'br-if-pair',
    'br-if-struct',
    'br-if-tc7',
    'br-if-true',
    'br-if-u64-<',
    'br-if-u64-<-scm',
    'br-if-u64-<=',
    'br-if-u64-<=-scm',
    'br-if-u64-=',
    'br-if-u64-=-scm',
    'break',
    'break!',
    'break-at-source',
    'broadcast-condition-variable',
    'buffer-mode',
    'buffer-mode?',
    'build-cont',
    'build-exp',
    'build-relative-ref',
    'build-request',
    'build-response',
    'build-term',
    'build-uri',
    'build-uri-reference',
    'builtin-ref',
    'bv-f32-ref',
    'bv-f32-set!',
    'bv-f64-ref',
    'bv-f64-set!',
    'bv-length',
    'bv-s16-ref',
    'bv-s16-set!',
    'bv-s32-ref',
    'bv-s32-set!',
    'bv-s64-ref',
    'bv-s64-set!',
    'bv-s8-ref',
    'bv-s8-set!',
    'bv-u16-ref',
    'bv-u16-set!',
    'bv-u32-ref',
    'bv-u32-set!',
    'bv-u64-ref',
    'bv-u64-set!',
    'bv-u8-ref',
    'bv-u8-set!',
    'bytevector->pointer',
    'bytevector->sint-list',
    'bytevector->string',
    'bytevector->u8-list',
    'bytevector->uint-list',
    'bytevector-copy',
    'bytevector-copy!',
    'bytevector-fill!',
    'bytevector-ieee-double-native-ref',
    'bytevector-ieee-double-native-set!',
    'bytevector-ieee-double-ref',
    'bytevector-ieee-double-set!',
    'bytevector-ieee-single-native-ref',
    'bytevector-ieee-single-native-set!',
    'bytevector-ieee-single-ref',
    'bytevector-ieee-single-set!',
    'bytevector-length',
    'bytevector-s16-native-ref',
    'bytevector-s16-native-set!',
    'bytevector-s16-ref',
    'bytevector-s16-set!',
    'bytevector-s32-native-ref',
    'bytevector-s32-native-set!',
    'bytevector-s32-ref',
    'bytevector-s32-set!',
    'bytevector-s64-native-ref',
    'bytevector-s64-native-set!',
    'bytevector-s64-ref',
    'bytevector-s64-set!',
    'bytevector-s8-ref',
    'bytevector-s8-set!',
    'bytevector-sint-ref',
    'bytevector-sint-set!',
    'bytevector-u16-native-ref',
    'bytevector-u16-native-set!',
    'bytevector-u16-ref',
    'bytevector-u16-set!',
    'bytevector-u32-native-ref',
    'bytevector-u32-native-set!',
    'bytevector-u32-ref',
    'bytevector-u32-set!',
    'bytevector-u64-native-ref',
    'bytevector-u64-native-set!',
    'bytevector-u64-ref',
    'bytevector-u64-set!',
    'bytevector-u8-ref',
    'bytevector-u8-set!',
    'bytevector-uint-ref',
    'bytevector-uint-set!',
    'bytevector=?',
    'bytevector?',
    'c32vector',
    'c32vector->list',
    'c32vector-length',
    'c32vector-ref',
    'c32vector-set!',
    'c32vector?',
    'c64vector',
    'c64vector->list',
    'c64vector-length',
    'c64vector-ref',
    'c64vector-set!',
    'c64vector?',
    'caaaar',
    'caaadr',
    'caaar',
    'caadar',
    'caaddr',
    'caadr',
    'caar',
    'cadaar',
    'cadadr',
    'cadar',
    'caddar',
    'cadddr',
    'caddr',
    'cadr',
    'call',
    'call-label',
    'call-with-allocation-limit',
    'call-with-blocked-asyncs',
    'call-with-current-continuation',
    'call-with-error-handling',
    'call-with-escape-continuation',
    'call-with-file-and-dir',
    'call-with-input-file',
    'call-with-input-string',
    'call-with-output-encoded-string',
    'call-with-output-file',
    'call-with-output-string',
    'call-with-port',
    'call-with-prompt',
    'call-with-stack-overflow-handler',
    'call-with-time-and-allocation-limits',
    'call-with-time-limit',
    'call-with-trace',
    'call-with-unblocked-asyncs',
    'call-with-values',
    'call/cc',
    'call/ec',
    'car',
    'car+cdr',
    'case',
    'case-lambda',
    'case-lambda*',
    'catch',
    'cd',
    'cdaaar',
    'cdaadr',
    'cdaar',
    'cdadar',
    'cdaddr',
    'cdadr',
    'cdar',
    'cddaar',
    'cddadr',
    'cddar',
    'cdddar',
    'cddddr',
    'cdddr',
    'cddr',
    'cdr',
    'ceiling',
    'ceiling-quotient',
    'ceiling-remainder',
    'ceiling/',
    'center-string',
    'centered-quotient',
    'centered-remainder',
    'centered/',
    'change-class',
    'char->formal-name',
    'char->integer',
    'char-alphabetic?',
    'char-ci<=?',
    'char-ci<?',
    'char-ci=?',
    'char-ci>=?',
    'char-ci>?',
    'char-downcase',
    'char-foldcase',
    'char-general-category',
    'char-is-both?',
    'char-locale-ci<?',
    'char-locale-ci=?',
    'char-locale-ci>?',
    'char-locale-downcase',
    'char-locale-titlecase',
    'char-locale-upcase',
    'char-locale<?',
    'char-locale>?',
    'char-lower-case?',
    'char-numeric?',
    'char-ready?',
    'char-set',
    'char-set->list',
    'char-set->string',
    'char-set-adjoin',
    'char-set-adjoin!',
    'char-set-any',
    'char-set-complement',
    'char-set-complement!',
    'char-set-contains?',
    'char-set-copy',
    'char-set-count',
    'char-set-cursor',
    'char-set-cursor-next',
    'char-set-delete',
    'char-set-delete!',
    'char-set-diff+intersection',
    'char-set-diff+intersection!',
    'char-set-difference',
    'char-set-difference!',
    'char-set-every',
    'char-set-filter',
    'char-set-filter!',
    'char-set-fold',
    'char-set-for-each',
    'char-set-hash',
    'char-set-intersection',
    'char-set-intersection!',
    'char-set-map',
    'char-set-ref',
    'char-set-size',
    'char-set-unfold',
    'char-set-unfold!',
    'char-set-union',
    'char-set-union!',
    'char-set-xor',
    'char-set-xor!',
    'char-set<=',
    'char-set=',
    'char-set?',
    'char-title-case?',
    'char-titlecase',
    'char-upcase',
    'char-upper-case?',
    'char-whitespace?',
    'char<=?',
    'char<?',
    'char=?',
    'char>=?',
    'char>?',
    'char?',
    'chdir',
    'chmod',
    'chown',
    'chroot',
    'circular-list',
    'circular-list?',
    'class',
    'class-direct-methods',
    'class-direct-slots',
    'class-direct-subclasses',
    'class-direct-supers',
    'class-methods',
    'class-name',
    'class-of',
    'class-precedence-list',
    'class-redefinition',
    'class-slot-definition',
    'class-slot-ref',
    'class-slot-set!',
    'class-slots',
    'class-subclasses',
    'clear-value-history!',
    'close',
    'close-fdes',
    'close-input-port',
    'close-output-port',
    'close-pipe',
    'close-port',
    'close-server',
    'closedir',
    'collapse-repeated-chars',
    'command-line',
    'compile',
    'compile-file',
    'compile-peg-pattern',
    'compiled-file-name',
    'complex?',
    'compose',
    'compose-continuation',
    'compute-std-cpl',
    'concatenate',
    'concatenate!',
    'cond',
    'cond-expand',
    'condition',
    'condition-accessor',
    'condition-has-type?',
    'condition-irritants',
    'condition-message',
    'condition-predicate',
    'condition-ref',
    'condition-type?',
    'condition-variable-broadcast!',
    'condition-variable-name',
    'condition-variable-signal!',
    'condition-variable-specific',
    'condition-variable-specific-set!',
    'condition-variable?',
    'condition-who',
    'condition?',
    'cons',
    'cons*',
    'cons-source',
    'const',
    'context-flatten',
    'continuation-call',
    'continue',
    'copy-bit',
    'copy-bit-field',
    'copy-file',
    'copy-random-state',
    'copy-time',
    'copy-tree',
    'cos',
    'cosh',
    'count',
    'coverage-data->lcov',
    'coverage-data?',
    'ctermid',
    'current-date',
    'current-dynamic-state',
    'current-error-port',
    'current-exception-handler',
    'current-filename',
    'current-http-proxy',
    'current-input-port',
    'current-julian-day',
    'current-load-port',
    'current-modified-julian-day',
    'current-module',
    'current-output-port',
    'current-read-waiter',
    'current-source-location',
    'current-ssax-error-port',
    'current-thread',
    'current-time',
    'current-write-waiter',
    'cut',
    'cute',
    'date->julian-day',
    'date->modified-julian-day',
    'date->string',
    'date->time-monotonic',
    'date->time-tai',
    'date->time-utc',
    'date-day',
    'date-hour',
    'date-minute',
    'date-month',
    'date-nanosecond',
    'date-second',
    'date-week-day',
    'date-week-number',
    'date-year',
    'date-year-day',
    'date-zone-offset',
    'date?',
    'datum->random-state',
    'datum->syntax',
    'debug-disable',
    'debug-enable',
    'debug-options',
    'debug-set!',
    'declare-default-port!',
    'declare-header!',
    'declare-opaque-header!',
    'deep-clone',
    'default-duplicate-binding-handler',
    'default-prompt-tag',
    'default-random-source',
    'define',
    'define!',
    'define*',
    'define*-public',
    'define-accessor',
    'define-class',
    'define-condition-type',
    'define-enumeration',
    'define-foreign-object-type',
    'define-generic',
    'define-immutable-record-type',
    'define-inlinable',
    'define-language',
    'define-macro',
    'define-method',
    'define-module',
    'define-once',
    'define-parsed-entity!',
    'define-peg-pattern',
    'define-peg-string-patterns',
    'define-public',
    'define-reader-ctor',
    'define-record-type',
    'define-server-impl',
    'define-stream',
    'define-syntax',
    'define-syntax-parameter',
    'define-syntax-rule',
    'define-values',
    'define-wrapped-pointer-type',
    'defined?',
    'defmacro',
    'defmacro*',
    'defmacro*-public',
    'defvar',
    'delay',
    'delete',
    'delete!',
    'delete-duplicates',
    'delete-duplicates!',
    'delete-file',
    'delete-trap!',
    'delete1!',
    'delq',
    'delq!',
    'delq1!',
    'delv',
    'delv!',
    'delv1!',
    'denominator',
    'deq!',
    'dereference-pointer',
    'describe',
    'directory-stream?',
    'dirname',
    'disable-trap!',
    'disable-value-history!',
    'disassemble',
    'disassemble-file',
    'display',
    'display-application',
    'display-backtrace',
    'display-error',
    'div',
    'div-and-mod',
    'div0',
    'div0-and-mod0',
    'do',
    'dotted-list?',
    'doubly-weak-hash-table?',
    'down',
    'drain-input',
    'drop',
    'drop-right',
    'drop-right!',
    'drop-while',
    'dup',
    'dup->fdes',
    'dup->inport',
    'dup->outport',
    'dup->port',
    'dup2',
    'duplicate-port',
    'dynamic-call',
    'dynamic-func',
    'dynamic-link',
    'dynamic-object?',
    'dynamic-pointer',
    'dynamic-state?',
    'dynamic-unlink',
    'dynamic-wind',
    'eager',
    'effective-version',
    'eighth',
    'else',
    'emit-begin-kw-arity',
    'emit-begin-opt-arity',
    'emit-begin-program',
    'emit-begin-standard-arity',
    'emit-br-if-bitvector',
    'emit-br-if-bytevector',
    'emit-br-if-string',
    'emit-br-if-symbol',
    'emit-br-if-variable',
    'emit-br-if-vector',
    'emit-cache-current-module!',
    'emit-cached-module-box',
    'emit-cached-toplevel-box',
    'emit-end-arity',
    'emit-end-program',
    'emit-label',
    'emit-load-constant',
    'emit-load-static-procedure',
    'emit-source',
    'emit-vector-length',
    'enable-primitive-generic!',
    'enable-trap!',
    'enable-value-history!',
    'encode-and-join-uri-path',
    'end-of-char-set?',
    'endianness',
    'enq!',
    'ensure-accessor',
    'ensure-generic',
    'ensure-metaclass',
    'enum-set->list',
    'enum-set-complement',
    'enum-set-constructor',
    'enum-set-difference',
    'enum-set-indexer',
    'enum-set-intersection',
    'enum-set-member?',
    'enum-set-projection',
    'enum-set-subset?',
    'enum-set-union',
    'enum-set-universe',
    'enum-set=?',
    'environ',
    'environment',
    'eof-object',
    'eof-object?',
    'eol-style',
    'eq?',
    'equal-hash',
    'equal?',
    'eqv?',
    'error',
    'error-handling-mode',
    'error-message',
    'error?',
    'escape-special-chars',
    'euclidean-quotient',
    'euclidean-remainder',
    'euclidean/',
    'eval',
    'eval-in-sandbox',
    'eval-string',
    'eval-when',
    'even?',
    'every',
    'exact',
    'exact->inexact',
    'exact-integer-sqrt',
    'exact-integer?',
    'exact?',
    'execl',
    'execle',
    'execlp',
    'exists',
    'exit',
    'exp',
    'expand',
    'expand-tabs',
    'expect',
    'expect-strings',
    'export',
    'export!',
    'expt',
    'extract-condition',
    'f32vector',
    'f32vector->list',
    'f32vector-length',
    'f32vector-ref',
    'f32vector-set!',
    'f32vector?',
    'f64->scm',
    'f64vector',
    'f64vector->list',
    'f64vector-length',
    'f64vector-ref',
    'f64vector-set!',
    'f64vector?',
    'fadd',
    'false-if-exception',
    'fchmod',
    'fchown',
    'fcntl',
    'fdes->inport',
    'fdes->outport',
    'fdes->ports',
    'fdiv',
    'fdopen',
    'feature?',
    'fflush',
    'fifth',
    'file-encoding',
    'file-exists?',
    'file-name-separator?',
    'file-options',
    'file-port?',
    'file-system-fold',
    'file-system-tree',
    'filename-completion-function',
    'fileno',
    'fill-string',
    'filter',
    'filter!',
    'filter-empty-elements',
    'filter-map',
    'find',
    'find-mapped-elf-image',
    'find-string-from-port?',
    'find-tail',
    'finish',
    'finite?',
    'first',
    'first-set-bit',
    'fixnum->flonum',
    'fixnum-width',
    'fixnum?',
    'fl*',
    'fl+',
    'fl-',
    'fl/',
    'fl<=?',
    'fl<?',
    'fl=?',
    'fl>=?',
    'fl>?',
    'flabs',
    'flacos',
    'flasin',
    'flatan',
    'flceiling',
    'flcos',
    'fldenominator',
    'fldiv',
    'fldiv-and-mod',
    'fldiv0',
    'fldiv0-and-mod0',
    'fldmod',
    'fleven?',
    'flexp',
    'flexpt',
    'flfinite?',
    'flfloor',
    'flinfinite?',
    'flinteger?',
    'fllog',
    'flmax',
    'flmin',
    'flmod0',
    'flnan?',
    'flnegative?',
    'flnumerator',
    'flock',
    'flodd?',
    'flonum?',
    'floor',
    'floor-quotient',
    'floor-remainder',
    'floor/',
    'flpositive?',
    'flround',
    'flsin',
    'flsqrt',
    'fltan',
    'fltruncate',
    'fluid->parameter',
    'fluid-bound?',
    'fluid-ref',
    'fluid-ref*',
    'fluid-set!',
    'fluid-thread-local?',
    'fluid-unset!',
    'fluid?',
    'flush-all-ports',
    'flush-output-port',
    'flzero?',
    'fmul',
    'fold',
    'fold-layout',
    'fold-left',
    'fold-matches',
    'fold-right',
    'fold-values',
    'foldt',
    'foldts',
    'foldts*',
    'foldts*-values',
    'for-all',
    'for-each',
    'force',
    'force-output',
    'foreign-call',
    'formal-name->char',
    'format',
    'fourth',
    'frame',
    'frame-address',
    'frame-arguments',
    'frame-bindings',
    'frame-dynamic-link',
    'frame-instruction-pointer',
    'frame-lookup-binding',
    'frame-mv-return-address',
    'frame-previous',
    'frame-procedure-name',
    'frame-return-address',
    'frame-stack-pointer',
    'frame?',
    'free-identifier=?',
    'free-ref',
    'free-set!',
    'fstat',
    'fsub',
    'fsync',
    'ftell',
    'ftruncate',
    'ftw',
    'future',
    'future?',
    'fx*',
    'fx*/carry',
    'fx+',
    'fx+/carry',
    'fx-',
    'fx-/carry',
    'fx<=?',
    'fx<?',
    'fx=?',
    'fx>=?',
    'fx>?',
    'fxand',
    'fxarithmetic-shift',
    'fxarithmetic-shift-left',
    'fxarithmetic-shift-right',
    'fxbit-count',
    'fxbit-field',
    'fxbit-set?',
    'fxcopy-bit',
    'fxcopy-bit-field',
    'fxdiv',
    'fxdiv-and-mod',
    'fxdiv0',
    'fxdiv0-and-mod0',
    'fxeven?',
    'fxfirst-bit-set',
    'fxif',
    'fxior',
    'fxlength',
    'fxmax',
    'fxmin',
    'fxmod',
    'fxmod0',
    'fxnegative?',
    'fxnot',
    'fxodd?',
    'fxpositive?',
    'fxreverse-bit-field',
    'fxrotate-bit-field',
    'fxxor',
    'fxzero?',
    'gc',
    'gcd',
    'gcprof',
    'generate-temporaries',
    'generic-function-methods',
    'generic-function-name',
    'gensym',
    'get-bytevector-all',
    'get-bytevector-n',
    'get-bytevector-n!',
    'get-bytevector-some',
    'get-bytevector-some!',
    'get-char',
    'get-datum',
    'get-environment-variable',
    'get-environment-variables',
    'get-internal-real-time',
    'get-internal-run-time',
    'get-line',
    'get-output-string',
    'get-string-all',
    'get-string-n',
    'get-string-n!',
    'get-u8',
    'getaffinity',
    'getcwd',
    'getegid',
    'getenv',
    'geteuid',
    'getgid',
    'getgroups',
    'getpgrp',
    'getpid',
    'getppid',
    'getpriority',
    'getsid',
    'getter-with-setter',
    'gettext',
    'gettimeofday',
    'getuid',
    'gmtime',
    'goops-error',
    'greatest-fixnum',
    'guard',
    'halt',
    'handle-interrupts',
    'handle-request',
    'hash',
    'hash-by-identity',
    'hash-clear!',
    'hash-count',
    'hash-create-handle!',
    'hash-fold',
    'hash-for-each',
    'hash-for-each-handle',
    'hash-get-handle',
    'hash-map->list',
    'hash-ref',
    'hash-remove!',
    'hash-set!',
    'hash-table->alist',
    'hash-table-delete!',
    'hash-table-equivalence-function',
    'hash-table-exists?',
    'hash-table-fold',
    'hash-table-hash-function',
    'hash-table-keys',
    'hash-table-ref',
    'hash-table-ref/default',
    'hash-table-set!',
    'hash-table-size',
    'hash-table-update!',
    'hash-table-update!/default',
    'hash-table-values',
    'hash-table-walk',
    'hash-table?',
    'hashq',
    'hashq-create-handle!',
    'hashq-get-handle',
    'hashq-ref',
    'hashq-remove!',
    'hashq-set!',
    'hashtable-clear!',
    'hashtable-contains?',
    'hashtable-copy',
    'hashtable-delete!',
    'hashtable-entries',
    'hashtable-equivalence-function',
    'hashtable-hash-function',
    'hashtable-keys',
    'hashtable-mutable?',
    'hashtable-ref',
    'hashtable-set!',
    'hashtable-size',
    'hashtable-update!',
    'hashtable?',
    'hashv',
    'hashv-create-handle!',
    'hashv-get-handle',
    'hashv-ref',
    'hashv-remove!',
    'hashv-set!',
    'hashx-create-handle!',
    'hashx-get-handle',
    'hashx-ref',
    'hashx-remove!',
    'hashx-set!',
    'header->string',
    'header-parser',
    'header-validator',
    'header-writer',
    'help',
    'hook->list',
    'hook-empty?',
    'hook?',
    'http',
    'http-delete',
    'http-get',
    'http-head',
    'http-options',
    'http-post',
    'http-put',
    'http-request',
    'http-trace',
    'i/o-decoding-error?',
    'i/o-encoding-error-char',
    'i/o-encoding-error?',
    'i/o-error-filename',
    'i/o-error-port',
    'i/o-error-position',
    'i/o-error?',
    'i/o-file-already-exists-error?',
    'i/o-file-does-not-exist-error?',
    'i/o-file-is-read-only-error?',
    'i/o-file-protection-error?',
    'i/o-filename-error?',
    'i/o-invalid-position-error?',
    'i/o-port-error?',
    'i/o-read-error?',
    'i/o-write-error?',
    'identifier-syntax',
    'identifier?',
    'identity',
    'if',
    'imag-part',
    'implementation-restriction-violation?',
    'import',
    'in',
    'include',
    'include-from-path',
    'inet-lnaof',
    'inet-makeaddr',
    'inet-netof',
    'inet-ntop',
    'inet-pton',
    'inexact',
    'inexact->exact',
    'inexact?',
    'inf',
    'inf?',
    'infinite?',
    'input-port?',
    'inspect',
    'install-suspendable-ports!',
    'install-trap-handler!',
    'instance?',
    'instrumented-source-files',
    'instrumented/executed-lines',
    'integer->char',
    'integer->list',
    'integer-expt',
    'integer-length',
    'integer-valued?',
    'integer?',
    'interaction-environment',
    'iota',
    'irritants-condition?',
    'is-a?',
    'isatty?',
    'join-timeout-exception?',
    'julian-day->date',
    'julian-day->time-monotonic',
    'julian-day->time-tai',
    'julian-day->time-utc',
    'keyword->string',
    'keyword->symbol',
    'keyword-flatten',
    'keyword?',
    'known-header?',
    'lalr-parser',
    'lambda',
    'lambda*',
    'language',
    'last',
    'last-pair',
    'latin-1-codec',
    'lazy',
    'lchown',
    'lcm',
    'least-fixnum',
    'left-justify-string',
    'length',
    'length+',
    'let',
    'let*',
    'let*-values',
    'let-escape-continuation',
    'let-keywords',
    'let-keywords*',
    'let-optional',
    'let-optional*',
    'let-syntax',
    'let-values',
    'let/ec',
    'letpar',
    'letrec',
    'letrec*',
    'letrec-syntax',
    'lexical-violation?',
    'library',
    'line-execution-counts',
    'link',
    'link-assembly',
    'list',
    'list->array',
    'list->bitvector',
    'list->c32vector',
    'list->c64vector',
    'list->char-set',
    'list->char-set!',
    'list->f32vector',
    'list->f64vector',
    'list->integer',
    'list->s16vector',
    'list->s32vector',
    'list->s64vector',
    'list->s8vector',
    'list->stream',
    'list->string',
    'list->symbol',
    'list->typed-array',
    'list->u16vector',
    'list->u32vector',
    'list->u64vector',
    'list->u8vector',
    'list->vector',
    'list->vlist',
    'list->weak-vector',
    'list-cdr-ref',
    'list-cdr-set!',
    'list-copy',
    'list-head',
    'list-index',
    'list-matches',
    'list-ref',
    'list-set!',
    'list-sort',
    'list-tabulate',
    'list-tail',
    'list-traps',
    'list=',
    'list?',
    'load',
    'load-compiled',
    'load-extension',
    'load-f64',
    'load-from-path',
    'load-s64',
    'load-thunk-from-file',
    'load-thunk-from-memory',
    'load-typed-array',
    'load-u64',
    'local-compile',
    'local-eval',
    'locale-am-string',
    'locale-currency-symbol',
    'locale-currency-symbol-precedes-negative?',
    'locale-currency-symbol-precedes-positive?',
    'locale-date+time-format',
    'locale-date-format',
    'locale-day',
    'locale-day-short',
    'locale-decimal-point',
    'locale-digit-grouping',
    'locale-encoding',
    'locale-era',
    'locale-era-date+time-format',
    'locale-era-date-format',
    'locale-era-time-format',
    'locale-era-year',
    'locale-monetary-decimal-point',
    'locale-monetary-fractional-digits',
    'locale-monetary-grouping',
    'locale-monetary-negative-sign',
    'locale-monetary-positive-sign',
    'locale-monetary-thousands-separator',
    'locale-month',
    'locale-month-short',
    'locale-negative-separated-by-space?',
    'locale-negative-sign-position',
    'locale-no-regexp',
    'locale-pm-string',
    'locale-positive-separated-by-space?',
    'locale-positive-sign-position',
    'locale-string->inexact',
    'locale-string->integer',
    'locale-thousands-separator',
    'locale-time+am/pm-format',
    'locale-time-format',
    'locale-yes-regexp',
    'locale?',
    'locals',
    'localtime',
    'lock-mutex',
    'log',
    'log10',
    'log2-binary-factors',
    'logand',
    'logbit?',
    'logcount',
    'logior',
    'lognot',
    'logsub',
    'logtest',
    'logxor',
    'long-fmov',
    'long-mov',
    'lookahead-char',
    'lookahead-u8',
    'lookup-compilation-order',
    'lookup-language',
    'lookup-server-impl',
    'lset-adjoin',
    'lset-diff+intersection',
    'lset-diff+intersection!',
    'lset-difference',
    'lset-difference!',
    'lset-intersection',
    'lset-intersection!',
    'lset-union',
    'lset-union!',
    'lset-xor',
    'lset-xor!',
    'lset<=',
    'lset=',
    'lstat',
    'macro-binding',
    'macro-name',
    'macro-transformer',
    'macro-type',
    'macro?',
    'magnitude',
    'major-version',
    'make',
    'make-accessor',
    'make-arity',
    'make-array',
    'make-assertion-violation',
    'make-atomic-box',
    'make-binding',
    'make-bitvector',
    'make-buffered-input-port',
    'make-bytevector',
    'make-c-struct',
    'make-c32vector',
    'make-c64vector',
    'make-chunked-input-port',
    'make-chunked-output-port',
    'make-class',
    'make-closure',
    'make-completion-function',
    'make-compound-condition',
    'make-condition',
    'make-condition-type',
    'make-condition-variable',
    'make-custom-binary-input-port',
    'make-custom-binary-input/output-port',
    'make-custom-binary-output-port',
    'make-date',
    'make-doubly-weak-hash-table',
    'make-empty-attlist',
    'make-enumeration',
    'make-eq-hashtable',
    'make-eqv-hashtable',
    'make-error',
    'make-f32vector',
    'make-f64vector',
    'make-fluid',
    'make-foreign-object-type',
    'make-future',
    'make-generic',
    'make-guardian',
    'make-hash-table',
    'make-hashtable',
    'make-hook',
    'make-i/o-decoding-error',
    'make-i/o-encoding-error',
    'make-i/o-error',
    'make-i/o-file-already-exists-error',
    'make-i/o-file-does-not-exist-error',
    'make-i/o-file-is-read-only-error',
    'make-i/o-file-protection-error',
    'make-i/o-invalid-position-error',
    'make-i/o-port-error',
    'make-i/o-read-error',
    'make-i/o-write-error',
    'make-implementation-restriction-violation',
    'make-instance',
    'make-io-filename-error',
    'make-irritants-condition',
    'make-lexical-violation',
    'make-line-buffered-input-port',
    'make-list',
    'make-locale',
    'make-long-immediate',
    'make-long-long-immediate',
    'make-message-condition',
    'make-method',
    'make-mutex',
    'make-no-infinities-violation',
    'make-no-nans-violation',
    'make-non-continuable-violation',
    'make-non-immediate',
    'make-object-property',
    'make-parameter',
    'make-pointer',
    'make-polar',
    'make-procedure-with-setter',
    'make-prompt-tag',
    'make-q',
    'make-random-source',
    'make-record-constructor-descriptor',
    'make-record-type',
    'make-record-type-descriptor',
    'make-rectangular',
    'make-recursive-mutex',
    'make-regexp',
    'make-s16vector',
    'make-s32vector',
    'make-s64vector',
    'make-s8vector',
    'make-sandbox-module',
    'make-serious-condition',
    'make-shared-array',
    'make-short-immediate',
    'make-soft-port',
    'make-stack',
    'make-stream',
    'make-string',
    'make-struct-layout',
    'make-struct/no-tail',
    'make-symbol',
    'make-syntax-transformer',
    'make-syntax-violation',
    'make-tcp-server-socket',
    'make-text-wrapper',
    'make-thread',
    'make-thread-local-fluid',
    'make-time',
    'make-transcoder',
    'make-typed-array',
    'make-u16vector',
    'make-u32vector',
    'make-u64vector',
    'make-u8vector',
    'make-unbound-fluid',
    'make-undefined-variable',
    'make-undefined-violation',
    'make-unix-domain-server-socket',
    'make-variable',
    'make-variable-transformer',
    'make-vector',
    'make-vector/immediate',
    'make-violation',
    'make-vtable',
    'make-warning',
    'make-weak-key-hash-table',
    'make-weak-value-hash-table',
    'make-weak-vector',
    'make-who-condition',
    'malloc-stats',
    'map',
    'map!',
    'map-in-order',
    'map-union',
    'match',
    'match-lambda',
    'match-lambda*',
    'match-let',
    'match-let*',
    'match-letrec',
    'match-pattern',
    'match:count',
    'match:end',
    'match:prefix',
    'match:start',
    'match:string',
    'match:substring',
    'match:suffix',
    'max',
    'member',
    'memp',
    'memq',
    'memv',
    'merge',
    'merge!',
    'message-condition?',
    'method',
    'method-generic-function',
    'method-procedure',
    'method-source',
    'method-specializers',
    'micro-version',
    'min',
    'minor-version',
    'mkdir',
    'mknod',
    'mkstemp!',
    'mktime',
    'mod',
    'mod0',
    'modified-julian-day->date',
    'modified-julian-day->time-monotonic',
    'modified-julian-day->time-tai',
    'modified-julian-day->time-utc',
    'module',
    'module-add!',
    'module-box',
    'module-define!',
    'module-ref',
    'module-set!',
    'module-stexi-documentation',
    'module-use!',
    'module-uses',
    'module-variable',
    'modulo',
    'modulo-expt',
    'monetary-amount->locale-string',
    'monitor',
    'mov',
    'move->fdes',
    'mul',
    'mutex-level',
    'mutex-lock!',
    'mutex-locked?',
    'mutex-name',
    'mutex-owner',
    'mutex-specific',
    'mutex-specific-set!',
    'mutex-state',
    'mutex-unlock!',
    'mutex?',
    'n-for-each-par-map',
    'n-par-for-each',
    'n-par-map',
    'nan',
    'nan?',
    'native-endianness',
    'native-eol-style',
    'native-transcoder',
    'negate',
    'negative?',
    'newline',
    'next',
    'next-token',
    'next-token-of',
    'nftw',
    'ngettext',
    'nice',
    'nil?',
    'ninth',
    'no-applicable-method',
    'no-infinities-violation?',
    'no-method',
    'no-nans-violation?',
    'no-next-method',
    'node-closure',
    'node-eq?',
    'node-equal?',
    'node-join',
    'node-or',
    'node-parent',
    'node-pos',
    'node-reduce',
    'node-reverse',
    'node-self',
    'node-trace',
    'node-typeof?',
    'nodeset?',
    'non-continuable-violation?',
    'not',
    'not-pair?',
    'null-environment',
    'null-list?',
    'null-pointer?',
    'null?',
    'number->locale-string',
    'number->string',
    'number?',
    'numerator',
    'object->string',
    'object-properties',
    'object-property',
    'object-stexi-documentation',
    'odd?',
    'open',
    'open-bytevector-input-port',
    'open-bytevector-output-port',
    'open-fdes',
    'open-file',
    'open-file-input-port',
    'open-file-output-port',
    'open-input-file',
    'open-input-output-pipe',
    'open-input-pipe',
    'open-input-string',
    'open-output-file',
    'open-output-pipe',
    'open-output-string',
    'open-pipe',
    'open-pipe*',
    'open-server',
    'open-socket-for-uri',
    'opendir',
    'optimize',
    'option',
    'option-ref',
    'or',
    'output-port?',
    'package-stexi-documentation',
    'package-stexi-documentation-for-include',
    'package-stexi-extended-menu',
    'package-stexi-generic-menu',
    'package-stexi-standard-copying',
    'package-stexi-standard-menu',
    'package-stexi-standard-prologue',
    'package-stexi-standard-titlepage',
    'pair-fold',
    'pair-fold-right',
    'pair-for-each',
    'pair?',
    'par-for-each',
    'par-map',
    'parallel',
    'parameterize',
    'parse-c-struct',
    'parse-header',
    'parse-http-method',
    'parse-http-version',
    'parse-path',
    'parse-path-with-ellipsis',
    'parse-request-uri',
    'partition',
    'partition!',
    'pclose',
    'peek-char',
    'peek-next-char',
    'peg-record?',
    'peg-string-compile',
    'peg:end',
    'peg:start',
    'peg:string',
    'peg:substring',
    'peg:tree',
    'pipe',
    'pointer->bytevector',
    'pointer->procedure',
    'pointer->scm',
    'pointer->string',
    'pointer-address',
    'pointer?',
    'poll-coop-repl-server',
    'pop',
    'pop-dynamic-state',
    'pop-fluid',
    'popen',
    'port->fdes',
    'port->stream',
    'port-closed?',
    'port-column',
    'port-conversion-strategy',
    'port-encoding',
    'port-eof?',
    'port-filename',
    'port-for-each',
    'port-has-port-position?',
    'port-has-set-port-position!?',
    'port-line',
    'port-mode',
    'port-position',
    'port-revealed',
    'port-transcoder',
    'port?',
    'positive?',
    'post-order',
    'pre-post-order',
    'pretty-print',
    'primitive-eval',
    'primitive-exit',
    'primitive-fork',
    'primitive-generic-generic',
    'primitive-load',
    'primitive-load-path',
    'primitive-move->fdes',
    'print-options',
    'print-set!',
    'procedure',
    'procedure->pointer',
    'procedure-documentation',
    'procedure-execution-count',
    'procedure-name',
    'procedure-properties',
    'procedure-property',
    'procedure-source',
    'procedure-with-setter?',
    'procedure?',
    'profile',
    'program-arguments',
    'program-arguments-alist',
    'program-arities',
    'program-arity',
    'program-bindings',
    'program-code',
    'program-free-variable-ref',
    'program-free-variable-set!',
    'program-lambda-list',
    'program-num-free-variable',
    'program-sources',
    'program?',
    'promise?',
    'prompt',
    'proper-list?',
    'provide',
    'provided?',
    'push',
    'push-dynamic-state',
    'push-fluid',
    'put-bytevector',
    'put-char',
    'put-datum',
    'put-string',
    'put-u8',
    'putenv',
    'pwd',
    'q-empty-check',
    'q-empty?',
    'q-front',
    'q-length',
    'q-pop!',
    'q-push!',
    'q-rear',
    'q-remove!',
    'q?',
    'quasiquote',
    'quasisyntax',
    'quit',
    'quo',
    'quote',
    'quotient',
    'raise',
    'raise-continuable',
    'random',
    'random-integer',
    'random-real',
    'random-source-make-integers',
    'random-source-make-reals',
    'random-source-pseudo-randomize!',
    'random-source-randomize!',
    'random-source-state-ref',
    'random-source-state-set!',
    'random-source?',
    'random-state->datum',
    'random-state-from-platform',
    'random:exp',
    'random:hollow-sphere!',
    'random:normal',
    'random:normal-vector!',
    'random:solid-sphere!',
    'random:uniform',
    'rational-valued?',
    'rational?',
    'rationalize',
    're-export',
    'read',
    'read-char',
    'read-client',
    'read-delimited',
    'read-delimited!',
    'read-disable',
    'read-enable',
    'read-hash-extend',
    'read-header',
    'read-headers',
    'read-line',
    'read-line!',
    'read-options',
    'read-request',
    'read-request-body',
    'read-request-line',
    'read-response',
    'read-response-body',
    'read-response-line',
    'read-set!',
    'read-string',
    'read-text-line',
    'read-with-shared-structure',
    'readdir',
    'readline',
    'readline-disable',
    'readline-enable',
    'readline-options',
    'readline-port',
    'readline-set!',
    'readlink',
    'real->flonum',
    'real-part',
    'real-valued?',
    'real?',
    'rec',
    'receive',
    'receive-values',
    'record-accessor',
    'record-constructor',
    'record-constructor-descriptor',
    'record-field-mutable?',
    'record-modifier',
    'record-mutator',
    'record-predicate',
    'record-rtd',
    'record-type-descriptor',
    'record-type-descriptor?',
    'record-type-field-names',
    'record-type-fields',
    'record-type-generative?',
    'record-type-name',
    'record-type-opaque?',
    'record-type-parent',
    'record-type-sealed?',
    'record-type-uid',
    'record?',
    'redirect-port',
    'reduce',
    'reduce-right',
    'regexp-exec',
    'regexp-match?',
    'regexp-quote',
    'regexp-substitute',
    'regexp-substitute/global',
    'regexp?',
    'registers',
    'relative-ref?',
    'release-port-handle',
    'reload',
    'reload-module',
    'rem',
    'remainder',
    'remove',
    'remove!',
    'remove-class-accessors!',
    'remove-fdes-finalizer!',
    'remove-hook!',
    'remp',
    'remq',
    'remv',
    'rename',
    'rename-file',
    'repl-default-option-set!',
    'replace-range',
    'replace-titles',
    'request-absolute-uri',
    'request-accept',
    'request-accept-charset',
    'request-accept-encoding',
    'request-accept-language',
    'request-allow',
    'request-authorization',
    'request-cache-control',
    'request-connection',
    'request-content-encoding',
    'request-content-language',
    'request-content-length',
    'request-content-location',
    'request-content-md5',
    'request-content-range',
    'request-content-type',
    'request-date',
    'request-expect',
    'request-expires',
    'request-from',
    'request-headers',
    'request-host',
    'request-if-match',
    'request-if-modified-since',
    'request-if-none-match',
    'request-if-range',
    'request-if-unmodified-since',
    'request-last-modified',
    'request-max-forwards',
    'request-meta',
    'request-method',
    'request-port',
    'request-pragma',
    'request-proxy-authorization',
    'request-range',
    'request-referer',
    'request-te',
    'request-trailer',
    'request-transfer-encoding',
    'request-upgrade',
    'request-uri',
    'request-user-agent',
    'request-version',
    'request-via',
    'request-warning',
    'request?',
    'require',
    'require-extension',
    'reset',
    'reset-frame',
    'reset-hook!',
    'reset-parsed-entity-definitions!',
    'resolve',
    'resolve-interface',
    'resolve-module',
    'response-accept-ranges',
    'response-age',
    'response-allow',
    'response-body-port',
    'response-cache-control',
    'response-code',
    'response-connection',
    'response-content-encoding',
    'response-content-language',
    'response-content-length',
    'response-content-location',
    'response-content-md5',
    'response-content-range',
    'response-content-type',
    'response-date',
    'response-etag',
    'response-expires',
    'response-headers',
    'response-last-modified',
    'response-location',
    'response-must-not-include-body?',
    'response-port',
    'response-pragma',
    'response-proxy-authenticate',
    'response-reason-phrase',
    'response-retry-after',
    'response-server',
    'response-trailer',
    'response-transfer-encoding',
    'response-upgrade',
    'response-vary',
    'response-version',
    'response-via',
    'response-warning',
    'response-www-authenticate',
    'response?',
    'restricted-vector-sort!',
    'return-from-interrupt',
    'return-values',
    'reverse',
    'reverse!',
    'reverse-bit-field',
    'reverse-list->string',
    'reverse-list->vector',
    'reverse-vector->list',
    'rewinddir',
    'rewrite-cont',
    'rewrite-exp',
    'rewrite-term',
    'right-justify-string',
    'rmdir',
    'rotate-bit-field',
    'round',
    'round-ash',
    'round-quotient',
    'round-remainder',
    'round/',
    'run-hook',
    'run-server',
    's16vector',
    's16vector->list',
    's16vector-length',
    's16vector-ref',
    's16vector-set!',
    's16vector?',
    's32vector',
    's32vector->list',
    's32vector-length',
    's32vector-ref',
    's32vector-set!',
    's32vector?',
    's64->scm',
    's64vector',
    's64vector->list',
    's64vector-length',
    's64vector-ref',
    's64vector-set!',
    's64vector?',
    's8vector',
    's8vector->list',
    's8vector-length',
    's8vector-ref',
    's8vector-set!',
    's8vector?',
    'sanitize-response',
    'save-module-excursion',
    'scandir',
    'scheme-report-environment',
    'scm->f64',
    'scm->pointer',
    'scm->s64',
    'scm->u64',
    'scm->u64/truncate',
    'scm-error',
    'script-stexi-documentation',
    'sdocbook-flatten',
    'search-for-pattern',
    'search-path',
    'second',
    'seconds->time',
    'seed->random-state',
    'seek',
    'select',
    'select-kids',
    'sendfile',
    'serious-condition?',
    'serve-one-client',
    'set!',
    'set-box!',
    'set-buffered-input-continuation?!',
    'set-car!',
    'set-cdr!',
    'set-current-dynamic-state',
    'set-current-error-port',
    'set-current-input-port',
    'set-current-module',
    'set-current-output-port',
    'set-field',
    'set-fields',
    'set-object-properties!',
    'set-object-property!',
    'set-port-column!',
    'set-port-conversion-strategy!',
    'set-port-encoding!',
    'set-port-filename!',
    'set-port-line!',
    'set-port-position!',
    'set-port-revealed!',
    'set-procedure-properties!',
    'set-procedure-property!',
    'set-program-arguments',
    'set-readline-input-port!',
    'set-readline-output-port!',
    'set-readline-prompt!',
    'set-record-type-printer!',
    'set-source-properties!',
    'set-source-property!',
    'set-struct-vtable-name!',
    'set-symbol-property!',
    'set-time-nanosecond!',
    'set-time-second!',
    'set-time-type!',
    'set-tm:gmtoff',
    'set-tm:hour',
    'set-tm:isdst',
    'set-tm:mday',
    'set-tm:min',
    'set-tm:mon',
    'set-tm:sec',
    'set-tm:wday',
    'set-tm:yday',
    'set-tm:year',
    'set-tm:zone',
    'set-vm-trace-level!',
    'setaffinity',
    'setegid',
    'setenv',
    'seteuid',
    'setgid',
    'setgroups',
    'setlocale',
    'setpgid',
    'setpriority',
    'setsid',
    'setter',
    'setuid',
    'setvbuf',
    'seventh',
    'shallow-clone',
    'shared-array-increments',
    'shared-array-offset',
    'shared-array-root',
    'shift',
    'show',
    'signal-condition-variable',
    'simple-conditions',
    'simple-format',
    'sin',
    'sinh',
    'sint-list->bytevector',
    'sixth',
    'sizeof',
    'skip-until',
    'skip-while',
    'sloppy-assoc',
    'sloppy-assq',
    'sloppy-assv',
    'slot-bound-using-class?',
    'slot-bound?',
    'slot-definition-accessor',
    'slot-definition-allocation',
    'slot-definition-getter',
    'slot-definition-init-form',
    'slot-definition-init-keyword',
    'slot-definition-init-thunk',
    'slot-definition-init-value',
    'slot-definition-name',
    'slot-definition-options',
    'slot-definition-setter',
    'slot-exists-using-class?',
    'slot-exists?',
    'slot-init-function',
    'slot-missing',
    'slot-ref',
    'slot-ref-using-class',
    'slot-set!',
    'slot-set-using-class!',
    'slot-unbound',
    'sort',
    'sort!',
    'sort-list',
    'sort-list!',
    'sorted?',
    'source-properties',
    'source-property',
    'source:addr',
    'source:column',
    'source:file',
    'source:line',
    'span',
    'span!',
    'spawn-coop-repl-server',
    'spawn-server',
    'split-and-decode-uri-path',
    'split-at',
    'split-at!',
    'sqrt',
    'ssax:complete-start-tag',
    'ssax:make-elem-parser',
    'ssax:make-parser',
    'ssax:make-pi-parser',
    'ssax:read-attributes',
    'ssax:read-cdata-body',
    'ssax:read-char-data',
    'ssax:read-char-ref',
    'ssax:read-external-id',
    'ssax:read-markup-token',
    'ssax:read-pi-body-as-string',
    'ssax:reverse-collect-str-drop-ws',
    'ssax:skip-internal-dtd',
    'ssax:uri-string->symbol',
    'ssax:xml->sxml',
    'stable-sort',
    'stable-sort!',
    'stack-id',
    'stack-length',
    'stack-ref',
    'stack?',
    'standard-error-port',
    'standard-input-port',
    'standard-output-port',
    'start-stack',
    'stat',
    'stat:atime',
    'stat:atimensec',
    'stat:blksize',
    'stat:blocks',
    'stat:ctime',
    'stat:ctimensec',
    'stat:dev',
    'stat:gid',
    'stat:ino',
    'stat:mode',
    'stat:mtime',
    'stat:mtimensec',
    'stat:nlink',
    'stat:perms',
    'stat:rdev',
    'stat:size',
    'stat:type',
    'stat:uid',
    'static-patch!',
    'static-ref',
    'static-set!',
    'statistics',
    'statprof',
    'statprof-accumulated-time',
    'statprof-active?',
    'statprof-call-data->stats',
    'statprof-call-data-calls',
    'statprof-call-data-cum-samples',
    'statprof-call-data-name',
    'statprof-call-data-self-samples',
    'statprof-display',
    'statprof-fetch-call-tree',
    'statprof-fetch-stacks',
    'statprof-fold-call-data',
    'statprof-proc-call-data',
    'statprof-reset',
    'statprof-sample-count',
    'statprof-start',
    'statprof-stats-calls',
    'statprof-stats-cum-secs-in-proc',
    'statprof-stats-cum-secs-per-call',
    'statprof-stats-proc-name',
    'statprof-stats-self-secs-in-proc',
    'statprof-stats-self-secs-per-call',
    'statprof-stop',
    'status:exit-val',
    'status:stop-sig',
    'status:term-sig',
    'step',
    'stexi->plain-text',
    'stexi->shtml',
    'stexi->sxml',
    'stexi->texi',
    'stexi-extract-index',
    'stop-server-and-clients!',
    'stream',
    'stream->list',
    'stream->list&length',
    'stream->reversed-list',
    'stream->reversed-list&length',
    'stream->vector',
    'stream-append',
    'stream-car',
    'stream-cdr',
    'stream-concat',
    'stream-cons',
    'stream-constant',
    'stream-drop',
    'stream-drop-while',
    'stream-filter',
    'stream-fold',
    'stream-for-each',
    'stream-from',
    'stream-iterate',
    'stream-lambda',
    'stream-length',
    'stream-let',
    'stream-map',
    'stream-match',
    'stream-null?',
    'stream-of',
    'stream-pair?',
    'stream-range',
    'stream-ref',
    'stream-reverse',
    'stream-scan',
    'stream-take',
    'stream-take-while',
    'stream-unfold',
    'stream-unfolds',
    'stream-zip',
    'stream?',
    'strerror',
    'strftime',
    'string',
    'string->bytevector',
    'string->char-set',
    'string->char-set!',
    'string->date',
    'string->header',
    'string->keyword',
    'string->list',
    'string->number',
    'string->pointer',
    'string->relative-ref',
    'string->symbol',
    'string->uri',
    'string->uri-reference',
    'string->utf16',
    'string->utf32',
    'string->utf8',
    'string->wrapped-lines',
    'string-any',
    'string-append',
    'string-append/shared',
    'string-bytes-per-char',
    'string-capitalize',
    'string-capitalize!',
    'string-ci->symbol',
    'string-ci-hash',
    'string-ci<',
    'string-ci<=',
    'string-ci<=?',
    'string-ci<>',
    'string-ci<?',
    'string-ci=',
    'string-ci=?',
    'string-ci>',
    'string-ci>=',
    'string-ci>=?',
    'string-ci>?',
    'string-compare',
    'string-compare-ci',
    'string-concatenate',
    'string-concatenate-reverse',
    'string-concatenate-reverse/shared',
    'string-concatenate/shared',
    'string-contains',
    'string-contains-ci',
    'string-copy',
    'string-copy!',
    'string-count',
    'string-delete',
    'string-downcase',
    'string-downcase!',
    'string-drop',
    'string-drop-right',
    'string-every',
    'string-fill!',
    'string-filter',
    'string-fold',
    'string-fold-right',
    'string-foldcase',
    'string-for-each',
    'string-for-each-index',
    'string-hash',
    'string-hash-ci',
    'string-index',
    'string-index-right',
    'string-join',
    'string-length',
    'string-locale-ci<?',
    'string-locale-ci=?',
    'string-locale-ci>?',
    'string-locale-downcase',
    'string-locale-titlecase',
    'string-locale-upcase',
    'string-locale<?',
    'string-locale>?',
    'string-map',
    'string-map!',
    'string-match',
    'string-normalize-nfc',
    'string-normalize-nfd',
    'string-normalize-nfkc',
    'string-normalize-nfkd',
    'string-null?',
    'string-pad',
    'string-pad-right',
    'string-prefix-ci?',
    'string-prefix-length',
    'string-prefix-length-ci',
    'string-prefix?',
    'string-ref',
    'string-replace',
    'string-reverse',
    'string-reverse!',
    'string-rindex',
    'string-set!',
    'string-skip',
    'string-skip-right',
    'string-split',
    'string-suffix-ci?',
    'string-suffix-length',
    'string-suffix-length-ci',
    'string-suffix?',
    'string-tabulate',
    'string-take',
    'string-take-right',
    'string-titlecase',
    'string-titlecase!',
    'string-tokenize',
    'string-trim',
    'string-trim-both',
    'string-trim-right',
    'string-unfold',
    'string-unfold-right',
    'string-upcase',
    'string-upcase!',
    'string-utf8-length',
    'string-xcopy!',
    'string<',
    'string<=',
    'string<=?',
    'string<>',
    'string<?',
    'string=',
    'string=?',
    'string>',
    'string>=',
    'string>=?',
    'string>?',
    'string?',
    'strptime',
    'strtod',
    'struct-ref',
    'struct-ref/immediate',
    'struct-ref/unboxed',
    'struct-set!',
    'struct-set!/immediate',
    'struct-set!/unboxed',
    'struct-vtable',
    'struct-vtable-name',
    'struct-vtable?',
    'struct?',
    'sub',
    'sub/immediate',
    'subr-call',
    'substring',
    'substring-fill!',
    'substring-move!',
    'substring/copy',
    'substring/read-only',
    'substring/shared',
    'subtract-duration',
    'subtract-duration!',
    'supports-source-properties?',
    'suspendable-continuation?',
    'sxml->string',
    'sxml->xml',
    'sxml-match',
    'sxml-match-let',
    'sxml-match-let*',
    'sxpath',
    'symbol',
    'symbol->keyword',
    'symbol->string',
    'symbol-append',
    'symbol-fref',
    'symbol-fset!',
    'symbol-hash',
    'symbol-interned?',
    'symbol-pref',
    'symbol-prefix-proc',
    'symbol-property',
    'symbol-property-remove!',
    'symbol-pset!',
    'symbol=?',
    'symbol?',
    'symlink',
    'sync',
    'sync-q!',
    'syntax',
    'syntax->datum',
    'syntax-case',
    'syntax-error',
    'syntax-local-binding',
    'syntax-locally-bound-identifiers',
    'syntax-module',
    'syntax-parameterize',
    'syntax-rules',
    'syntax-source',
    'syntax-violation',
    'syntax-violation-form',
    'syntax-violation-subform',
    'syntax-violation?',
    'system',
    'system*',
    'system-async-mark',
    'system-error-errno',
    'system-file-name-convention',
    'tail-apply',
    'tail-call',
    'tail-call-label',
    'tail-call/shuffle',
    'take',
    'take!',
    'take-after',
    'take-right',
    'take-until',
    'take-while',
    'take-while!',
    'tan',
    'tanh',
    'tcgetpgrp',
    'tcsetpgrp',
    'tenth',
    'terminated-thread-exception?',
    'texi->stexi',
    'texi-command-depth',
    'texi-fragment->stexi',
    'text-content-type?',
    'textdomain',
    'textual-port?',
    'the-environment',
    'third',
    'thread-join!',
    'thread-name',
    'thread-sleep!',
    'thread-specific',
    'thread-specific-set!',
    'thread-start!',
    'thread-terminate!',
    'thread-yield!',
    'thread?',
    'throw',
    'thunk?',
    'time',
    'time->seconds',
    'time-difference',
    'time-difference!',
    'time-monotonic->date',
    'time-monotonic->time-tai',
    'time-monotonic->time-tai!',
    'time-monotonic->time-utc',
    'time-monotonic->time-utc!',
    'time-nanosecond',
    'time-resolution',
    'time-second',
    'time-tai->date',
    'time-tai->julian-day',
    'time-tai->modified-julian-day',
    'time-tai->time-monotonic',
    'time-tai->time-monotonic!',
    'time-tai->time-utc',
    'time-tai->time-utc!',
    'time-type',
    'time-utc->date',
    'time-utc->julian-day',
    'time-utc->modified-julian-day',
    'time-utc->time-monotonic',
    'time-utc->time-monotonic!',
    'time-utc->time-tai',
    'time-utc->time-tai!',
    'time<=?',
    'time<?',
    'time=?',
    'time>=?',
    'time>?',
    'time?',
    'times',
    'tm:gmtoff',
    'tm:hour',
    'tm:isdst',
    'tm:mday',
    'tm:min',
    'tm:mon',
    'tm:sec',
    'tm:wday',
    'tm:yday',
    'tm:year',
    'tm:zone',
    'tmpfile',
    'tmpnam',
    'tms:clock',
    'tms:cstime',
    'tms:cutime',
    'tms:stime',
    'tms:utime',
    'toplevel-box',
    'touch',
    'trace',
    'trace-calls-in-procedure',
    'trace-calls-to-procedure',
    'trace-instructions-in-procedure',
    'tracepoint',
    'transcoded-port',
    'transcoder-codec',
    'transcoder-eol-style',
    'transcoder-error-handling-mode',
    'transform-string',
    'transpose-array',
    'trap-at-procedure-call',
    'trap-at-procedure-ip-in-range',
    'trap-at-source-location',
    'trap-calls-in-dynamic-extent',
    'trap-calls-to-procedure',
    'trap-enabled?',
    'trap-frame-finish',
    'trap-in-dynamic-extent',
    'trap-in-procedure',
    'trap-instructions-in-dynamic-extent',
    'trap-instructions-in-procedure',
    'trap-matching-instructions',
    'trap-name',
    'truncate',
    'truncate-file',
    'truncate-quotient',
    'truncate-remainder',
    'truncate/',
    'truncated-print',
    'try-mutex',
    'ttyname',
    'typed-array?',
    'tzset',
    'u16vector',
    'u16vector->list',
    'u16vector-length',
    'u16vector-ref',
    'u16vector-set!',
    'u16vector?',
    'u32vector',
    'u32vector->list',
    'u32vector-length',
    'u32vector-ref',
    'u32vector-set!',
    'u32vector?',
    'u64->scm',
    'u64vector',
    'u64vector->list',
    'u64vector-length',
    'u64vector-ref',
    'u64vector-set!',
    'u64vector?',
    'u8-list->bytevector',
    'u8vector',
    'u8vector->list',
    'u8vector-length',
    'u8vector-ref',
    'u8vector-set!',
    'u8vector?',
    'uadd',
    'uadd/immediate',
    'ucs-range->char-set',
    'ucs-range->char-set!',
    'uint-list->bytevector',
    'ulogand',
    'ulogior',
    'ulogsub',
    'ulogxor',
    'ulsh',
    'ulsh/immediate',
    'umask',
    'umul',
    'umul/immediate',
    'unbox',
    'uncaught-exception-reason',
    'uncaught-exception?',
    'undefined-violation?',
    'unfold',
    'unfold-right',
    'unget-bytevector',
    'unget-char',
    'unget-string',
    'uninstall-suspendable-ports!',
    'unless',
    'unlink',
    'unlock-mutex',
    'unquote',
    'unquote-splicing',
    'unread-char',
    'unread-string',
    'unsetenv',
    'unsyntax',
    'unsyntax-splicing',
    'unwind',
    'unzip1',
    'unzip2',
    'unzip3',
    'unzip4',
    'unzip5',
    'up',
    'update-direct-method!',
    'update-direct-subclass!',
    'update-instance-for-different-class',
    'uri->string',
    'uri-decode',
    'uri-encode',
    'uri-fragment',
    'uri-host',
    'uri-path',
    'uri-port',
    'uri-query',
    'uri-reference?',
    'uri-scheme',
    'uri-userinfo',
    'uri?',
    'urlify',
    'ursh',
    'ursh/immediate',
    'use-modules',
    'usub',
    'usub/immediate',
    'utf-16-codec',
    'utf-8-codec',
    'utf16->string',
    'utf32->string',
    'utf8->string',
    'utime',
    'valid-header?',
    'value-history-enabled?',
    'values',
    'variable-bound?',
    'variable-ref',
    'variable-set!',
    'variable-unset!',
    'variable?',
    'vector',
    'vector->list',
    'vector->stream',
    'vector-any',
    'vector-append',
    'vector-binary-search',
    'vector-concatenate',
    'vector-copy',
    'vector-copy!',
    'vector-count',
    'vector-empty?',
    'vector-every',
    'vector-fill!',
    'vector-fold',
    'vector-fold-right',
    'vector-for-each',
    'vector-index',
    'vector-index-right',
    'vector-length',
    'vector-map',
    'vector-map!',
    'vector-move-left!',
    'vector-move-right!',
    'vector-ref',
    'vector-ref/immediate',
    'vector-reverse!',
    'vector-reverse-copy',
    'vector-reverse-copy!',
    'vector-set!',
    'vector-set!/immediate',
    'vector-skip',
    'vector-skip-right',
    'vector-sort',
    'vector-sort!',
    'vector-swap!',
    'vector-unfold',
    'vector-unfold-right',
    'vector=',
    'vector?',
    'version',
    'vhash-assoc',
    'vhash-assq',
    'vhash-assv',
    'vhash-cons',
    'vhash-consq',
    'vhash-consv',
    'vhash-delete',
    'vhash-delq',
    'vhash-delv',
    'vhash-fold',
    'vhash-fold*',
    'vhash-fold-right',
    'vhash-foldq*',
    'vhash-foldv*',
    'vhash?',
    'violation?',
    'vlist->list',
    'vlist-append',
    'vlist-cons',
    'vlist-delete',
    'vlist-drop',
    'vlist-filter',
    'vlist-fold',
    'vlist-fold-right',
    'vlist-for-each',
    'vlist-head',
    'vlist-length',
    'vlist-map',
    'vlist-null?',
    'vlist-ref',
    'vlist-reverse',
    'vlist-tail',
    'vlist-take',
    'vlist-unfold',
    'vlist-unfold-right',
    'vlist?',
    'vm-abort-continuation-hook',
    'vm-apply-hook',
    'vm-next-hook',
    'vm-pop-continuation-hook',
    'vm-push-continuation-hook',
    'vm-restore-continuation-hook',
    'vm-trace-level',
    'wait-condition-variable',
    'waitpid',
    'warning?',
    'weak-key-hash-table?',
    'weak-value-hash-table?',
    'weak-vector',
    'weak-vector-ref',
    'weak-vector-set!',
    'weak-vector?',
    'when',
    'while',
    'who-condition?',
    'width',
    'wind',
    'with-code-coverage',
    'with-continuation-barrier',
    'with-default-trap-handler',
    'with-dynamic-state',
    'with-ellipsis',
    'with-error-to-file',
    'with-error-to-port',
    'with-exception-handler',
    'with-fluid*',
    'with-fluids',
    'with-fluids*',
    'with-input-from-file',
    'with-input-from-port',
    'with-input-from-string',
    'with-mutex',
    'with-output-to-file',
    'with-output-to-port',
    'with-output-to-string',
    'with-parameters*',
    'with-readline-completion-function',
    'with-ssax-error-to-port',
    'with-syntax',
    'with-throw-handler',
    'write',
    'write-char',
    'write-client',
    'write-header',
    'write-headers',
    'write-request',
    'write-request-body',
    'write-request-line',
    'write-response',
    'write-response-body',
    'write-response-line',
    'write-with-shared-structure',
    'xcons',
    'xml->sxml',
    'xml-token-head',
    'xml-token-kind',
    'xml-token?',
    'xsubstring',
    'zero?',
    'zip',
]

scheme_functions = [
    'accidental-interface::calc-alteration',
    'accidental-interface::calc-glyph-name',
    'add-bar-glyph-print-procedure',
    'add-grace-property',
    'add-lyrics',
    'add-music',
    'add-music-fonts',
    'add-new-clef',
    'add-pango-fonts',
    'add-point',
    'add-quotable',
    'add-score',
    'add-simple-time-signature-style',
    'add-stroke-glyph',
    'add-stroke-straight',
    'add-text',
    'adjust-slash-stencil',
    'alist->hash-table',
    'alist<?',
    'alist?',
    'all-bar-numbers-visible',
    'all-repeat-counts-visible',
    'allow-volta-hook',
    'alteration->text-accidental-markup',
    'alterations-in-key',
    'ambitus-line::calc-gap',
    'ambitus::print',
    'annotate-padding',
    'annotate-spacing-spec',
    'annotate-y-interval',
    'argument-error',
    'arrow-stencil',
    'arrow-stencil-maker',
    'attributes',
    'average',
    'bar-line::calc-break-visibility',
    'bar-line::calc-glyph-name',
    'bar-line::calc-glyph-name-for-direction',
    'bar-line::compound-bar-line',
    'bar-line::draw-filled-box',
    'bar-line::widen-bar-extent-on-span',
    'base-length',
    'beam-exceptions',
    'beam::align-with-broken-parts',
    'beam::get-kievan-positions',
    'beam::get-kievan-quantized-positions',
    'beam::place-broken-parts-individually',
    'beam::slope-like-broken-parts',
    'beat-structure',
    'bend-spanner::print',
    'bend::arrow-head-stencil',
    'bend::calc-bend-x-begin',
    'bend::calc-bend-x-end',
    'bend::print',
    'bend::target-cautionary',
    'bend::text-string',
    'binary-search',
    'book-first-page',
    'boolean-or-number?',
    'boolean-or-symbol?',
    'box-grob-stencil',
    'box-stencil',
    'bracketify-stencil',
    'break-alignable-interface::self-alignment-of-anchor',
    'break-alignable-interface::self-alignment-opposite-of-anchor',
    'break-alignment-list',
    'breathe::midi-length',
    'cached-file-contents',
    'caesura-script-interface::before-line-breaking',
    'caesura-to-bar-line-or-divisio',
    'caesura-to-divisio',
    'calc-harmonic-pitch',
    'calc-printable-height',
    'calculate-compound-base-beat',
    'calculate-compound-beat-grouping',
    'calculate-compound-measure-length',
    'call-after-session',
    'centered-spanner-interface::calc-x-offset',
    'centered-stencil',
    'change-pitches',
    'cheap-list?',
    'check-context-path',
    'check-grob-path',
    'check-music-path',
    'check-quant-callbacks',
    'check-slope-callbacks',
    'chord-square::height',
    'chord-square::print',
    'chord-square::width',
    'circle-stencil',
    'clef-transposition-markup',
    'clef::print-modern-tab-if-set',
    'close-port-rename',
    'collect-book-music-for-book',
    'collect-bookpart-for-book',
    'collect-music-aux',
    'collect-music-for-book',
    'collect-scores-for-book',
    'color?',
    'comment',
    'completize-formats',
    'composed-markup-list',
    'construct-chord-elements',
    'context-change',
    'context-create',
    'context-defs-from-music',
    'context-find-or-create',
    'context-mod-from-music',
    'context-spec-music',
    'control-polygon::calc-text',
    'convert-to-pdf',
    'convert-to-png',
    'convert-to-ps',
    'coord-rotate',
    'coord-rotated',
    'coord-scale',
    'coord-translate',
    'copy-binary-file',
    'copy-repeat-chord',
    'count-list',
    'create-file-exclusive',
    'create-glyph-flag',
    'create-script',
    'cross-staff-connect',
    'cue-substitute',
    'cyclic-base-value',
    'debugf',
    'def-grace-function',
    'default-auto-beam-check',
    'default-flag',
    'define-bar-line',
    'define-event-class',
    'define-event-function',
    'define-fonts',
    'define-markup-command',
    'define-markup-command-internal',
    'define-markup-list-command',
    'define-music-function',
    'define-scheme-function',
    'define-syntax-function',
    'define-tag-group',
    'define-void-function',
    'degrees->radians',
    'descend-to-context',
    'determine-frets',
    'determine-split-list',
    'determine-string-fret-finger',
    'dir-basename',
    'display-lily-music',
    'display-music',
    'display-scheme-music',
    'dodecaphonic-no-repeat-rule',
    'dot-column-interface::pad-by-one-dot-width',
    'dots::calc-dot-count',
    'dots::calc-dot-stencil',
    'dots::calc-glyph-name',
    'dots::calc-staff-position',
    'dump-stencil-as-EPS',
    'duration->lily-string',
    'duration-dot-factor',
    'duration-length',
    'duration-line::calc',
    'duration-line::calc-thickness',
    'duration-line::print',
    'duration-log-factor',
    'duration-of-note',
    'duration-or-music?',
    'duration-visual',
    'duration-visual-length',
    'dynamic-text-spanner::before-line-breaking',
    'ec',
    'ellipse-radius',
    'ellipse-stencil',
    'empty-music',
    'end-broken-spanner?',
    'entity',
    'eo',
    'eoc',
    'eps-file->stencil',
    'eval-carefully',
    'event-cause',
    'event-chord',
    'event-chord-notes',
    'event-chord-pitches',
    'event-chord-reduce',
    'event-class-cons',
    'event-has-articulation?',
    'exact-rational?',
    'extract-beam-exceptions',
    'extract-music',
    'extract-named-music',
    'extract-typed-music',
    'find-child',
    'find-child-named',
    'find-named-props',
    'find-pitch-entry',
    'fingering::calc-text',
    'first-assoc',
    'first-bar-number-invisible',
    'first-bar-number-invisible-and-no-parenthesized-bar-numbers',
    'first-bar-number-invisible-save-broken-bars',
    'first-broken-spanner?',
    'first-member',
    'flat-flag',
    'flatten-alist',
    'flatten-list',
    'flip-stencil',
    'fold-some-music',
    'font-name-split',
    'font-name-style',
    'for-some-music',
    'format-bass-figure',
    'format-dal-segno-text',
    'format-dal-segno-text-brief',
    'format-mark-generic',
    'format-metronome-markup',
    'format-segno-mark-considering-bar-lines',
    'fraction->moment',
    'fraction?',
    'fret->pitch',
    'fret-board::calc-stencil',
    'fret-letter-tablature-format',
    'fret-number-tablature-format',
    'fret-number-tablature-format-banjo',
    'fret-parse-terse-definition-string',
    'function-chain',
    'generate-crop-stencil',
    'generate-preview-stencil',
    'get-bound-note-heads',
    'get-chord-shape',
    'get-next-unique-voice-name',
    'get-postscript-bbox',
    'get-tweakable-music',
    'get-woodwind-key-list',
    'glissando::calc-tab-extra-dy',
    'glissando::draw-tab-glissando',
    'grace-spacing::calc-shortest-duration',
    'grob-interpret-markup',
    'grob-list?',
    'grob-transformer',
    'grob::all-objects',
    'grob::compose-function',
    'grob::display-objects',
    'grob::has-interface',
    'grob::is-live?',
    'grob::name',
    'grob::offset-function',
    'grob::rhythmic-location',
    'grob::show-skylines-if-debug-skylines-set',
    'grob::unpure-Y-extent-from-stencil',
    'grob::when',
    'gs-cmd-args',
    'gs-safe-run',
    'gulp-file',
    'hairpin::calc-grow-direction',
    'hash-table->alist',
    'headers-property-alist-chain',
    'hook-stencil',
    'horizontal-slash-interval',
    'identifiers-doc-string',
    'ignatzek-chord-names',
    'index-or-markup?',
    'index?',
    'interpret-markup-list',
    'interval-bound',
    'interval-center',
    'interval-contains?',
    'interval-empty?',
    'interval-index',
    'interval-intersection',
    'interval-length',
    'interval-sane?',
    'interval-scale',
    'interval-union',
    'interval-widen',
    'invalidate-alterations',
    'is-absolute?',
    'item::extra-spacing-height-including-staff',
    'key-list-or-music?',
    'key-list-or-symbol?',
    'key-list?',
    'key-signature-interface::alteration-position',
    'key-signature-interface::alteration-positions',
    'key?',
    'layout->page-init',
    'layout-extract-page-properties',
    'layout-line-thickness',
    'layout-set-absolute-staff-size',
    'layout-set-absolute-staff-size-in-module',
    'layout-set-staff-size',
    'lilypond-all',
    'lilypond-main',
    'lilypond-version',
    'lilypond-version-outdated?',
    'list-insert-separator',
    'list-join',
    'lookup-markup-command',
    'lookup-markup-list-command',
    'ly-getcwd',
    'ly:accidental-interface::height',
    'ly:accidental-interface::horizontal-skylines',
    'ly:accidental-interface::print',
    'ly:accidental-interface::remove-tied',
    'ly:accidental-placement::calc-positioning-done',
    'ly:add-context-mod',
    'ly:add-interface',
    'ly:add-listener',
    'ly:add-option',
    'ly:align-interface::align-to-ideal-distances',
    'ly:align-interface::align-to-minimum-distances',
    'ly:alist-ci<?',
    'ly:alist<?',
    'ly:all-grob-interfaces',
    'ly:all-options',
    'ly:all-output-backend-commands',
    'ly:all-stencil-commands',
    'ly:all-stencil-expressions',
    'ly:alternative-sequence-iterator::constructor',
    'ly:angle',
    'ly:apply-context-iterator::constructor',
    'ly:arpeggio::calc-cross-staff',
    'ly:arpeggio::calc-positions',
    'ly:arpeggio::print',
    'ly:arpeggio::pure-height',
    'ly:arpeggio::width',
    'ly:assoc-get',
    'ly:axis-group-interface::add-element',
    'ly:axis-group-interface::adjacent-pure-heights',
    'ly:axis-group-interface::calc-pure-relevant-grobs',
    'ly:axis-group-interface::calc-pure-staff-staff-spacing',
    'ly:axis-group-interface::calc-pure-y-common',
    'ly:axis-group-interface::calc-skylines',
    'ly:axis-group-interface::calc-staff-staff-spacing',
    'ly:axis-group-interface::calc-x-common',
    'ly:axis-group-interface::calc-y-common',
    'ly:axis-group-interface::combine-skylines',
    'ly:axis-group-interface::height',
    'ly:axis-group-interface::pure-height',
    'ly:axis-group-interface::pure-height?',
    'ly:axis-group-interface::width',
    'ly:balloon-interface::print',
    'ly:balloon-interface::pure-height',
    'ly:balloon-interface::remove-irrelevant-spanner',
    'ly:balloon-interface::width',
    'ly:bar-check-iterator::constructor',
    'ly:bar-line::calc-anchor',
    'ly:bar-line::calc-bar-extent',
    'ly:bar-line::print',
    'ly:basic-progress',
    'ly:beam::calc-beam-segments',
    'ly:beam::calc-beaming',
    'ly:beam::calc-cross-staff',
    'ly:beam::calc-direction',
    'ly:beam::calc-normal-stems',
    'ly:beam::calc-stem-shorten',
    'ly:beam::calc-x-positions',
    'ly:beam::print',
    'ly:beam::quanting',
    'ly:beam::set-stem-lengths',
    'ly:bezier-extent',
    'ly:bezier-extract',
    'ly:book-add-bookpart!',
    'ly:book-add-score!',
    'ly:book-book-parts',
    'ly:book-header',
    'ly:book-paper',
    'ly:book-process',
    'ly:book-process-to-systems',
    'ly:book-scores',
    'ly:book-set-header!',
    'ly:book?',
    'ly:bp',
    'ly:bracket',
    'ly:break-alignable-interface::find-parent',
    'ly:break-alignable-interface::self-align-callback',
    'ly:break-aligned-interface::calc-average-anchor',
    'ly:break-aligned-interface::calc-break-visibility',
    'ly:break-aligned-interface::calc-extent-aligned-anchor',
    'ly:break-aligned-interface::calc-joint-anchor-alignment',
    'ly:break-alignment-interface::calc-positioning-done',
    'ly:break-alignment-interface::find-nonempty-break-align-group',
    'ly:breathing-sign::divisio-maior',
    'ly:breathing-sign::divisio-maxima',
    'ly:breathing-sign::divisio-minima',
    'ly:breathing-sign::finalis',
    'ly:breathing-sign::offset-callback',
    'ly:breathing-sign::set-breath-properties',
    'ly:broadcast',
    'ly:cairo-output-stencil',
    'ly:cairo-output-stencils',
    'ly:calculated-sequential-music::length',
    'ly:calculated-sequential-music::start',
    'ly:camel-case->lisp-identifier',
    'ly:chain-assoc-get',
    'ly:change-iterator::constructor',
    'ly:char-ci<?',
    'ly:char-generic-<?',
    'ly:char<?',
    'ly:check-expected-warnings',
    'ly:chord-name::after-line-breaking',
    'ly:clef-modifier::calc-parent-alignment',
    'ly:clef::calc-glyph-name',
    'ly:clef::print',
    'ly:cluster-beacon::height',
    'ly:cluster::calc-cross-staff',
    'ly:cluster::print',
    'ly:cm',
    'ly:command-line-code',
    'ly:command-line-options',
    'ly:connect-dispatchers',
    'ly:context-current-moment',
    'ly:context-def-lookup',
    'ly:context-def-modify',
    'ly:context-def?',
    'ly:context-event-source',
    'ly:context-events-below',
    'ly:context-find',
    'ly:context-grob-definition',
    'ly:context-id',
    'ly:context-matched-pop-property',
    'ly:context-mod-apply!',
    'ly:context-mod?',
    'ly:context-name',
    'ly:context-output-def',
    'ly:context-parent',
    'ly:context-property',
    'ly:context-property-where-defined',
    'ly:context-pushpop-property',
    'ly:context-set-property!',
    'ly:context-specced-music-iterator::constructor',
    'ly:context-unset-property',
    'ly:context?',
    'ly:custos::print',
    'ly:debug',
    'ly:default-scale',
    'ly:dimension?',
    'ly:dir?',
    'ly:directed',
    'ly:disconnect-dispatchers',
    'ly:dispatcher?',
    'ly:dot-column::calc-positioning-done',
    'ly:dots::print',
    'ly:duration->string',
    'ly:duration-compress',
    'ly:duration-dot-count',
    'ly:duration-factor',
    'ly:duration-length',
    'ly:duration-log',
    'ly:duration-scale',
    'ly:duration<?',
    'ly:duration?',
    'ly:effective-prefix',
    'ly:enclosing-bracket::print',
    'ly:enclosing-bracket::width',
    'ly:engraver-announce-end-grob',
    'ly:engraver-make-grob',
    'ly:engraver-make-item',
    'ly:engraver-make-spanner',
    'ly:engraver-make-sticky',
    'ly:error',
    'ly:event-chord-iterator::constructor',
    'ly:event-deep-copy',
    'ly:event-property',
    'ly:event-set-property!',
    'ly:event-warning',
    'ly:event?',
    'ly:exit',
    'ly:expect-warning',
    'ly:extract-subfont-from-collection',
    'ly:figured-bass-continuation::center-on-figures',
    'ly:figured-bass-continuation::print',
    'ly:find-file',
    'ly:fine-iterator::constructor',
    'ly:fingering-column::calc-positioning-done',
    'ly:flag::calc-x-offset',
    'ly:flag::calc-y-offset',
    'ly:flag::glyph-name',
    'ly:flag::print',
    'ly:flag::pure-calc-y-offset',
    'ly:flag::stencil',
    'ly:flag::width',
    'ly:font-config-add-directory',
    'ly:font-config-add-font',
    'ly:font-config-display-fonts',
    'ly:font-config-get-font-file',
    'ly:font-design-size',
    'ly:font-file-name',
    'ly:font-get-glyph',
    'ly:font-glyph-name-to-charcode',
    'ly:font-glyph-name-to-index',
    'ly:font-index-to-charcode',
    'ly:font-magnification',
    'ly:font-metric?',
    'ly:font-name',
    'ly:font-sub-fonts',
    'ly:format',
    'ly:format-output',
    'ly:generic-bound-extent',
    'ly:get-all-function-documentation',
    'ly:get-all-translators',
    'ly:get-cff-offset',
    'ly:get-context-mods',
    'ly:get-font-format',
    'ly:get-option',
    'ly:get-spacing-spec',
    'ly:grace-iterator::constructor',
    'ly:grace-music::start-callback',
    'ly:grid-line-interface::print',
    'ly:grid-line-interface::width',
    'ly:grob-alist-chain',
    'ly:grob-array->list',
    'ly:grob-array-length',
    'ly:grob-array-ref',
    'ly:grob-array?',
    'ly:grob-basic-properties',
    'ly:grob-chain-callback',
    'ly:grob-common-refpoint',
    'ly:grob-common-refpoint-of-array',
    'ly:grob-default-font',
    'ly:grob-extent',
    'ly:grob-get-vertical-axis-group-index',
    'ly:grob-interfaces',
    'ly:grob-layout',
    'ly:grob-list->grob-array',
    'ly:grob-object',
    'ly:grob-original',
    'ly:grob-parent',
    'ly:grob-pq<?',
    'ly:grob-properties?',
    'ly:grob-property',
    'ly:grob-property-data',
    'ly:grob-pure-height',
    'ly:grob-pure-property',
    'ly:grob-relative-coordinate',
    'ly:grob-robust-relative-extent',
    'ly:grob-script-priority-less',
    'ly:grob-set-nested-property!',
    'ly:grob-set-object!',
    'ly:grob-set-parent!',
    'ly:grob-set-property!',
    'ly:grob-spanned-column-rank-interval',
    'ly:grob-staff-position',
    'ly:grob-suicide!',
    'ly:grob-system',
    'ly:grob-translate-axis!',
    'ly:grob-vertical<?',
    'ly:grob-warning',
    'ly:grob::horizontal-skylines-from-element-stencils',
    'ly:grob::horizontal-skylines-from-stencil',
    'ly:grob::pure-horizontal-skylines-from-element-stencils',
    'ly:grob::pure-simple-horizontal-skylines-from-extents',
    'ly:grob::pure-simple-vertical-skylines-from-extents',
    'ly:grob::pure-vertical-skylines-from-element-stencils',
    'ly:grob::stencil-height',
    'ly:grob::vertical-skylines-from-element-stencils',
    'ly:grob::vertical-skylines-from-stencil',
    'ly:grob::x-parent-positioning',
    'ly:grob?',
    'ly:gs-api',
    'ly:gs-cli',
    'ly:gulp-file',
    'ly:gulp-file-utf8',
    'ly:hairpin::broken-bound-padding',
    'ly:hairpin::print',
    'ly:hairpin::pure-height',
    'ly:hara-kiri-group-spanner::calc-skylines',
    'ly:hara-kiri-group-spanner::force-hara-kiri-callback',
    'ly:hara-kiri-group-spanner::pure-height',
    'ly:hara-kiri-group-spanner::y-extent',
    'ly:has-glyph-names?',
    'ly:hash-table-keys',
    'ly:horizontal-bracket-text::calc-direction',
    'ly:horizontal-bracket-text::print',
    'ly:horizontal-bracket::print',
    'ly:horizontal-line-spanner::calc-left-bound-info',
    'ly:horizontal-line-spanner::calc-left-bound-info-and-text',
    'ly:horizontal-line-spanner::calc-right-bound-info',
    'ly:in-event-class?',
    'ly:inch',
    'ly:input-both-locations',
    'ly:input-file-line-char-column',
    'ly:input-location?',
    'ly:input-message',
    'ly:input-warning',
    'ly:interpret-music-expression',
    'ly:intlog2',
    'ly:item-break-dir',
    'ly:item-get-column',
    'ly:item?',
    'ly:iterator?',
    'ly:key-signature-interface::print',
    'ly:kievan-ligature::print',
    'ly:ledger-line-spanner::print',
    'ly:ledger-line-spanner::set-spacing-rods',
    'ly:length',
    'ly:lily-lexer?',
    'ly:lily-parser?',
    'ly:line-interface::line',
    'ly:line-spanner::calc-cross-staff',
    'ly:line-spanner::calc-left-bound-info',
    'ly:line-spanner::calc-right-bound-info',
    'ly:line-spanner::print',
    'ly:list->offsets',
    'ly:listened-event-class?',
    'ly:listened-event-types',
    'ly:listener?',
    'ly:load',
    'ly:lyric-combine-music-iterator::constructor',
    'ly:lyric-extender::print',
    'ly:lyric-hyphen::print',
    'ly:lyric-hyphen::set-spacing-rods',
    'ly:make-book',
    'ly:make-book-part',
    'ly:make-context-mod',
    'ly:make-dispatcher',
    'ly:make-duration',
    'ly:make-event-class',
    'ly:make-global-context',
    'ly:make-global-translator',
    'ly:make-grob-properties',
    'ly:make-listener',
    'ly:make-moment',
    'ly:make-music',
    'ly:make-music-function',
    'ly:make-music-relative!',
    'ly:make-output-def',
    'ly:make-page-label-marker',
    'ly:make-page-permission-marker',
    'ly:make-pango-description-string',
    'ly:make-paper-outputter',
    'ly:make-pitch',
    'ly:make-prob',
    'ly:make-rotation',
    'ly:make-scale',
    'ly:make-scaling',
    'ly:make-score',
    'ly:make-skyline',
    'ly:make-spring',
    'ly:make-stencil',
    'ly:make-stream-event',
    'ly:make-transform',
    'ly:make-translation',
    'ly:make-unpure-pure-container',
    'ly:measure-grouping::print',
    'ly:measure-spanner::calc-connect-to-neighbors',
    'ly:measure-spanner::print',
    'ly:mensural-ligature::print',
    'ly:message',
    'ly:minimal-breaking',
    'ly:mm',
    'ly:module->alist',
    'ly:module-copy',
    'ly:modules-lookup',
    'ly:moment->string',
    'ly:moment-add',
    'ly:moment-div',
    'ly:moment-grace',
    'ly:moment-grace-denominator',
    'ly:moment-grace-numerator',
    'ly:moment-main',
    'ly:moment-main-denominator',
    'ly:moment-main-numerator',
    'ly:moment-mod',
    'ly:moment-mul',
    'ly:moment-sub',
    'ly:moment<?',
    'ly:moment?',
    'ly:multi-measure-rest::height',
    'ly:multi-measure-rest::print',
    'ly:multi-measure-rest::set-spacing-rods',
    'ly:multi-measure-rest::set-text-rods',
    'ly:music-compress',
    'ly:music-deep-copy',
    'ly:music-duration-compress',
    'ly:music-duration-length',
    'ly:music-error',
    'ly:music-function-extract',
    'ly:music-function-signature',
    'ly:music-function?',
    'ly:music-iterator::constructor',
    'ly:music-length',
    'ly:music-list?',
    'ly:music-message',
    'ly:music-mutable-properties',
    'ly:music-output?',
    'ly:music-property',
    'ly:music-sequence::cumulative-length-callback',
    'ly:music-sequence::event-chord-length-callback',
    'ly:music-sequence::event-chord-relative-callback',
    'ly:music-sequence::first-start-callback',
    'ly:music-sequence::maximum-length-callback',
    'ly:music-sequence::minimum-start-callback',
    'ly:music-sequence::simultaneous-relative-callback',
    'ly:music-set-property!',
    'ly:music-start',
    'ly:music-transpose',
    'ly:music-warning',
    'ly:music-wrapper-iterator::constructor',
    'ly:music-wrapper::length-callback',
    'ly:music-wrapper::start-callback',
    'ly:music?',
    'ly:non-fatal-error',
    'ly:note-collision-interface::calc-positioning-done',
    'ly:note-column-accidentals',
    'ly:note-column-dot-column',
    'ly:note-column::calc-main-extent',
    'ly:note-extra-source-file',
    'ly:note-head::calc-stem-attachment',
    'ly:note-head::calc-tab-stem-attachment',
    'ly:note-head::include-ledger-line-height',
    'ly:note-head::print',
    'ly:note-head::stem-attachment',
    'ly:note-head::stem-x-shift',
    'ly:number->string',
    'ly:number-pair->string',
    'ly:one-line-auto-height-breaking',
    'ly:one-line-breaking',
    'ly:one-page-breaking',
    'ly:optimal-breaking',
    'ly:option-usage',
    'ly:otf->cff',
    'ly:otf-font-glyph-info',
    'ly:otf-font-table-data',
    'ly:otf-font?',
    'ly:otf-glyph-count',
    'ly:otf-glyph-list',
    'ly:ottava-bracket::print',
    'ly:output-def-clone',
    'ly:output-def-lookup',
    'ly:output-def-parent',
    'ly:output-def-scope',
    'ly:output-def-set-variable!',
    'ly:output-def?',
    'ly:output-description',
    'ly:output-find-context-def',
    'ly:outputter-close',
    'ly:outputter-dump-stencil',
    'ly:outputter-dump-string',
    'ly:outputter-output-scheme',
    'ly:outputter-port',
    'ly:page-marker?',
    'ly:page-turn-breaking',
    'ly:pango-font-physical-fonts',
    'ly:pango-font?',
    'ly:paper-book-header',
    'ly:paper-book-pages',
    'ly:paper-book-paper',
    'ly:paper-book-performances',
    'ly:paper-book-scopes',
    'ly:paper-book-systems',
    'ly:paper-book?',
    'ly:paper-column::break-align-width',
    'ly:paper-column::print',
    'ly:paper-fonts',
    'ly:paper-get-font',
    'ly:paper-get-number',
    'ly:paper-outputscale',
    'ly:paper-score-paper-systems',
    'ly:paper-system-minimum-distance',
    'ly:paper-system?',
    'ly:parse-file',
    'ly:parse-init',
    'ly:parse-string-expression',
    'ly:parsed-undead-list!',
    'ly:parser-clear-error',
    'ly:parser-clone',
    'ly:parser-define!',
    'ly:parser-error',
    'ly:parser-has-error?',
    'ly:parser-include-string',
    'ly:parser-lookup',
    'ly:parser-output-name',
    'ly:parser-parse-string',
    'ly:parser-set-note-names',
    'ly:part-combine-iterator::constructor',
    'ly:partial-iterator::constructor',
    'ly:percent-repeat-interface::beat-slash',
    'ly:percent-repeat-interface::double-percent',
    'ly:percent-repeat-interface::percent',
    'ly:percent-repeat-iterator::constructor',
    'ly:perform-text-replacements',
    'ly:performance-headers',
    'ly:performance-write',
    'ly:piano-pedal-bracket::print',
    'ly:pitch-alteration',
    'ly:pitch-diff',
    'ly:pitch-negate',
    'ly:pitch-notename',
    'ly:pitch-octave',
    'ly:pitch-quartertones',
    'ly:pitch-semitones',
    'ly:pitch-steps',
    'ly:pitch-tones',
    'ly:pitch-transpose',
    'ly:pitch<?',
    'ly:pitch?',
    'ly:pointer-group-interface::add-grob',
    'ly:pop-property-iterator::constructor',
    'ly:position-on-line?',
    'ly:prob-immutable-properties',
    'ly:prob-mutable-properties',
    'ly:prob-property',
    'ly:prob-property?',
    'ly:prob-set-property!',
    'ly:prob-type?',
    'ly:prob?',
    'ly:programming-error',
    'ly:progress',
    'ly:property-iterator::constructor',
    'ly:property-lookup-stats',
    'ly:property-unset-iterator::constructor',
    'ly:pt',
    'ly:pure-call',
    'ly:pure-from-neighbor-interface::calc-pure-relevant-grobs',
    'ly:push-property-iterator::constructor',
    'ly:quote-iterator::constructor',
    'ly:randomize-rand-seed',
    'ly:register-stencil-expression',
    'ly:register-translator',
    'ly:relative-group-extent',
    'ly:relative-octave-check::relative-callback',
    'ly:relative-octave-music::no-relative-callback',
    'ly:relative-octave-music::relative-callback',
    'ly:rename-file',
    'ly:reset-all-fonts',
    'ly:rest-collision::calc-positioning-done',
    'ly:rest::calc-cross-staff',
    'ly:rest::height',
    'ly:rest::print',
    'ly:rest::pure-height',
    'ly:rest::width',
    'ly:rest::y-offset-callback',
    'ly:rhythmic-music-iterator::constructor',
    'ly:round-filled-box',
    'ly:round-polygon',
    'ly:run-translator',
    'ly:score-add-output-def!',
    'ly:score-embedded-format',
    'ly:score-error?',
    'ly:score-header',
    'ly:score-music',
    'ly:score-output-defs',
    'ly:score-set-header!',
    'ly:score?',
    'ly:script-column::before-line-breaking',
    'ly:script-column::row-before-line-breaking',
    'ly:script-interface::calc-cross-staff',
    'ly:script-interface::calc-direction',
    'ly:script-interface::calc-positioning-done',
    'ly:script-interface::print',
    'ly:self-alignment-interface::aligned-on-x-parent',
    'ly:self-alignment-interface::centered-on-x-parent',
    'ly:self-alignment-interface::pure-y-aligned-on-self',
    'ly:self-alignment-interface::x-aligned-on-self',
    'ly:self-alignment-interface::y-aligned-on-self',
    'ly:semi-tie-column::calc-head-direction',
    'ly:semi-tie-column::calc-positioning-done',
    'ly:semi-tie::calc-control-points',
    'ly:separation-item::calc-skylines',
    'ly:sequential-iterator::constructor',
    'ly:set-color-names',
    'ly:set-default-scale',
    'ly:set-grob-creation-callback',
    'ly:set-grob-modification-callback',
    'ly:set-middle-C!',
    'ly:set-option',
    'ly:set-origin!',
    'ly:set-property-cache-callback',
    'ly:shutdown-gs',
    'ly:side-position-interface::calc-cross-staff',
    'ly:side-position-interface::move-to-extremal-staff',
    'ly:side-position-interface::pure-y-aligned-side',
    'ly:side-position-interface::x-aligned-side',
    'ly:side-position-interface::y-aligned-side',
    'ly:simple-music-iterator::constructor',
    'ly:simultaneous-music-iterator::constructor',
    'ly:skyline->points',
    'ly:skyline-distance',
    'ly:skyline-empty?',
    'ly:skyline-height',
    'ly:skyline-max-height',
    'ly:skyline-max-height-position',
    'ly:skyline-merge',
    'ly:skyline-pad',
    'ly:skyline-pair?',
    'ly:skyline-touching-point',
    'ly:skyline?',
    'ly:skylines-for-stencil',
    'ly:slur::calc-control-points',
    'ly:slur::calc-cross-staff',
    'ly:slur::calc-direction',
    'ly:slur::height',
    'ly:slur::print',
    'ly:slur::pure-height',
    'ly:smob-protects',
    'ly:solve-spring-rod-problem',
    'ly:source-file?',
    'ly:source-files',
    'ly:spacing-spanner::calc-common-shortest-duration',
    'ly:spacing-spanner::set-springs',
    'ly:span-bar::before-line-breaking',
    'ly:span-bar::calc-anchor',
    'ly:span-bar::calc-glyph-name',
    'ly:span-bar::choose-model-bar-line',
    'ly:span-bar::print',
    'ly:span-bar::width',
    'ly:spanner-bound',
    'ly:spanner-broken-into',
    'ly:spanner-set-bound!',
    'ly:spanner::calc-normalized-endpoints',
    'ly:spanner::kill-zero-spanned-time',
    'ly:spanner::set-spacing-rods',
    'ly:spanner?',
    'ly:spawn',
    'ly:spring-set-inverse-compress-strength!',
    'ly:spring-set-inverse-stretch-strength!',
    'ly:spring?',
    'ly:staff-symbol-line-thickness',
    'ly:staff-symbol-referencer::callback',
    'ly:staff-symbol-staff-radius',
    'ly:staff-symbol-staff-space',
    'ly:staff-symbol::height',
    'ly:staff-symbol::print',
    'ly:stderr-redirect',
    'ly:stem-tremolo::calc-cross-staff',
    'ly:stem-tremolo::calc-direction',
    'ly:stem-tremolo::calc-shape',
    'ly:stem-tremolo::calc-slope',
    'ly:stem-tremolo::calc-width',
    'ly:stem-tremolo::calc-y-offset',
    'ly:stem-tremolo::print',
    'ly:stem-tremolo::pure-calc-y-offset',
    'ly:stem-tremolo::pure-height',
    'ly:stem-tremolo::width',
    'ly:stem::calc-cross-staff',
    'ly:stem::calc-default-direction',
    'ly:stem::calc-direction',
    'ly:stem::calc-length',
    'ly:stem::calc-positioning-done',
    'ly:stem::calc-stem-begin-position',
    'ly:stem::calc-stem-info',
    'ly:stem::height',
    'ly:stem::offset-callback',
    'ly:stem::print',
    'ly:stem::pure-calc-length',
    'ly:stem::pure-calc-stem-begin-position',
    'ly:stem::pure-height',
    'ly:stem::width',
    'ly:stencil-add',
    'ly:stencil-aligned-to',
    'ly:stencil-combine-at-edge',
    'ly:stencil-empty?',
    'ly:stencil-expr',
    'ly:stencil-extent',
    'ly:stencil-in-color',
    'ly:stencil-outline',
    'ly:stencil-rotate',
    'ly:stencil-rotate-absolute',
    'ly:stencil-scale',
    'ly:stencil-stack',
    'ly:stencil-translate',
    'ly:stencil-translate-axis',
    'ly:stencil?',
    'ly:stream-event?',
    'ly:string-ci<?',
    'ly:string-generic-<?',
    'ly:string-percent-encode',
    'ly:string-substitute',
    'ly:string<?',
    'ly:sustain-pedal::print',
    'ly:symbol-ci<?',
    'ly:symbol<?',
    'ly:system',
    'ly:system-font-load',
    'ly:system-start-delimiter::print',
    'ly:system::calc-pure-height',
    'ly:system::calc-pure-relevant-grobs',
    'ly:system::footnotes-after-line-breaking',
    'ly:system::footnotes-before-line-breaking',
    'ly:system::get-spaceable-staves',
    'ly:system::get-staves',
    'ly:system::get-vertical-alignment',
    'ly:system::height',
    'ly:system::vertical-skyline-elements',
    'ly:text-interface::interpret-markup',
    'ly:text-interface::print',
    'ly:tie-column::before-line-breaking',
    'ly:tie-column::calc-positioning-done',
    'ly:tie::calc-control-points',
    'ly:tie::calc-direction',
    'ly:tie::print',
    'ly:time-signature::print',
    'ly:transform->list',
    'ly:transform?',
    'ly:translate-cpp-warning-scheme',
    'ly:translator-context',
    'ly:translator-description',
    'ly:translator-group?',
    'ly:translator-name',
    'ly:translator?',
    'ly:transpose-key-alist',
    'ly:ttf->pfa',
    'ly:ttf-ps-name',
    'ly:tuplet-bracket::calc-connect-to-neighbors',
    'ly:tuplet-bracket::calc-cross-staff',
    'ly:tuplet-bracket::calc-direction',
    'ly:tuplet-bracket::calc-positions',
    'ly:tuplet-bracket::calc-x-positions',
    'ly:tuplet-bracket::print',
    'ly:tuplet-iterator::constructor',
    'ly:tuplet-number::calc-cross-staff',
    'ly:tuplet-number::calc-x-offset',
    'ly:tuplet-number::calc-y-offset',
    'ly:tuplet-number::print',
    'ly:type1->pfa',
    'ly:unit',
    'ly:unpure-call',
    'ly:unpure-pure-container-pure-part',
    'ly:unpure-pure-container-unpure-part',
    'ly:unpure-pure-container?',
    'ly:usage',
    'ly:vaticana-ligature::print',
    'ly:verbose-output?',
    'ly:version',
    'ly:version?',
    'ly:volta-bracket-interface::print',
    'ly:volta-bracket::calc-shorten-pair',
    'ly:volta-repeat-iterator::constructor',
    'ly:volta-specced-music-iterator::constructor',
    'ly:vowel-transition::set-spacing-rods',
    'ly:warning',
    'ly:warning-located',
    'ly:wide-char->utf-8',
    'lyric-combine',
    'lyric-event',
    'lyric-hyphen::vaticana-style',
    'lyric-text::print',
    'magnification->font-size',
    'magstep',
    'make-apply-context',
    'make-articulation',
    'make-autochange-music',
    'make-bow-stencil',
    'make-c-time-signature-markup',
    'make-circle-stencil',
    'make-clef-set',
    'make-connected-line',
    'make-connected-path-stencil',
    'make-cue-clef-set',
    'make-cue-clef-unset',
    'make-default-fonts-tree',
    'make-duration-of-length',
    'make-ellipse-stencil',
    'make-engraver',
    'make-event-chord',
    'make-filled-box-stencil',
    'make-glyph-time-signature-markup',
    'make-grace-music',
    'make-graceless-rhythmic-location',
    'make-grob-property-override',
    'make-grob-property-revert',
    'make-grob-property-set',
    'make-harmonic',
    'make-line-stencil',
    'make-lyric-event',
    'make-lyric-repeat-count-formatter',
    'make-modal-inverter',
    'make-modal-transposer',
    'make-multi-measure-rest',
    'make-music',
    'make-non-relative-music',
    'make-oval-stencil',
    'make-page',
    'make-pango-font-tree',
    'make-part-combine-context-changes',
    'make-part-combine-marks',
    'make-partial-ellipse-stencil',
    'make-path-stencil',
    'make-performer',
    'make-property-set',
    'make-property-unset',
    'make-ps-images',
    'make-relative',
    'make-repeat',
    'make-rhythmic-location',
    'make-semitone->pitch',
    'make-sequential-music',
    'make-setting',
    'make-simultaneous-music',
    'make-skip-music',
    'make-span-event',
    'make-stencil-boxer',
    'make-stencil-circler',
    'make-tie-stencil',
    'make-tmpfile',
    'make-translator',
    'make-transparent-box-stencil',
    'make-type-checker',
    'make-voice-props-override',
    'make-voice-props-revert',
    'make-voice-props-set',
    'map-selected-alist-keys',
    'map-some-music',
    'markup',
    'markup->lily-string',
    'markup->string',
    'markup-command-list?',
    'markup-default-to-string-method',
    'markup-function?',
    'markup-lambda',
    'markup-lambda-listify',
    'markup-lambda-worker',
    'markup-list-lambda',
    'markup-list?',
    'measure-counter::text',
    'memoize-clef-names',
    'mensural-flag',
    'middle-broken-spanner?',
    'midi-program',
    'mkdir-if-not-exist',
    'mmrest-of-length',
    'modern-straight-flag',
    'modified-font-metric-font-scaling',
    'moment->fraction',
    'moment-min',
    'moment-pair?',
    'move-chord-note',
    'multi-measure-rest',
    'music->lily-string',
    'music->make-music',
    'music-clone',
    'music-elements',
    'music-filter',
    'music-function',
    'music-function-call-error',
    'music-has-property?',
    'music-invert',
    'music-is-of-type?',
    'music-map',
    'music-name?',
    'music-pitches',
    'music-property-value?',
    'music-property?',
    'music-selective-filter',
    'music-selective-map',
    'music-separator?',
    'music-to-musicxml',
    'music-to-xml',
    'music-type-predicate',
    'neo-modern-accidental-rule',
    'no-flag',
    'normal-flag',
    'not-first-broken-spanner?',
    'not-last-broken-spanner?',
    'note-head::brew-ez-stencil',
    'note-head::calc-duration-log',
    'note-head::calc-glyph-name',
    'note-head::calc-kievan-duration-log',
    'note-name->german-markup',
    'note-name->lily-string',
    'note-name->markup',
    'note-name->string',
    'note-name-markup',
    'note-names-language',
    'note-to-cluster',
    'notes-to-clusters',
    'number-format',
    'number-list?',
    'number-or-grob?',
    'number-or-pair?',
    'number-or-string?',
    'number-pair-list?',
    'number-pair?',
    'numbered-footnotes',
    'object-type',
    'object-type-name',
    'octave->lily-string',
    'offset-add',
    'offset-flip-y',
    'offset-fret',
    'offset-scale',
    'offsetter',
    'old-straight-flag',
    'only-if-beamed',
    'ordered-cons',
    'other-axis',
    'output-file',
    'output-module?',
    'output-scopes',
    'output-stencil',
    'output-stencils',
    'oval-stencil',
    'override-head-style',
    'override-time-signature-setting',
    'page-stencil',
    'pango-pf-file-name',
    'pango-pf-font-name',
    'pango-pf-fontindex',
    'paper-system-annotate',
    'paper-system-annotate-last',
    'paper-system-extent',
    'paper-system-layout',
    'paper-system-staff-extents',
    'paper-system-stencil',
    'paper-system-system-grob',
    'paper-system-title?',
    'parentheses-interface::calc-angled-bracket-stencils',
    'parentheses-interface::calc-parenthesis-stencils',
    'parentheses-interface::print',
    'parentheses-interface::y-extent',
    'parenthesize-elements',
    'parenthesize-stencil',
    'parse-terse-string',
    'partial-markup',
    'partial-music-function',
    'partial-text-script',
    'percussion?',
    'pitch-invert',
    'pitch-of-note',
    'polar->rectangular',
    'postprocess-output',
    'postscript->pdf',
    'postscript->png',
    'postscript->ps',
    'prepend-alist-chain',
    'pretty-printable?',
    'print-book-with-defaults',
    'print-book-with-defaults-as-systems',
    'print-circled-text-callback',
    'print-keys',
    'print-keys-verbose',
    'process-music',
    'property-revert',
    'property-unset',
    'property-value',
    'ps-embed-cff',
    'ps-font-command',
    'ps-page-count',
    'pure-chain-offset-callback',
    'pure-from-neighbor-interface::account-for-span-bar',
    'pure-from-neighbor-interface::extra-spacing-height',
    'pure-from-neighbor-interface::extra-spacing-height-at-beginning-of-line',
    'pure-from-neighbor-interface::extra-spacing-height-including-staff',
    'pure-from-neighbor-interface::pure-height',
    'randomize-rand-seed',
    'ratio->fret',
    'ratio->pitch',
    'rational-or-procedure?',
    'read-lily-expression',
    'recording-group-emulate',
    'remove-grace-property',
    'remove-whitespace',
    'repeat-alt',
    'repeat-tie::handle-tab-note-head',
    'repetition-chord',
    'reset-stencil-colors',
    'retrieve-glyph-flag',
    'retrograde-music',
    'reverse-interval',
    'revert-fontSize',
    'revert-head-style',
    'revert-props',
    'revert-time-signature-setting',
    'rgb-color',
    'rhythmic-location->file-string',
    'rhythmic-location->string',
    'rhythmic-location<?',
    'rhythmic-location>?',
    'rhythmic-location?',
    'robust-bar-number-function',
    'rounded-box-stencil',
    'safe-car',
    'safe-last',
    'scale->factor',
    'scale-beam-thickness',
    'scale-by-font-size',
    'scale-fontSize',
    'scale-layout',
    'scale-props',
    'scale?',
    'scheme?',
    'scm->string',
    'scorify-music',
    'script-interface::calc-x-offset',
    'script-or-side-position-cross-staff',
    'search-executable',
    'seconds->moment',
    'select-head-glyph',
    'self-alignment-interface::self-aligned-on-breakable',
    'semi-tie::calc-cross-staff',
    'sequential-alternative-music',
    'sequential-music',
    'sequential-music-to-chord-exceptions',
    'session-replay',
    'session-save',
    'session-start-record',
    'set-accidental-style',
    'set-default-paper-size',
    'set-global-fonts',
    'set-global-staff-size',
    'set-paper-dimension-variables',
    'set-paper-size',
    'shift-duration-log',
    'shift-one-duration-log',
    'shift-right-at-line-begin',
    'sign',
    'simultaneous-music',
    'skip->rest',
    'skip-of-length',
    'skip-of-moment-span',
    'skyline-pair-and-non-empty?',
    'skyline-pair::empty?',
    'space-lines',
    'span-bar::compound-bar-line',
    'split-list-by-separator',
    'stack-lines',
    'stack-stencil-line',
    'stack-stencils',
    'stack-stencils-padding-list',
    'staff-ellipsis::calc-y-extent',
    'staff-ellipsis::print',
    'staff-symbol::calc-widened-extent',
    'stderr',
    'stem-stub::extra-spacing-height',
    'stem-stub::pure-height',
    'stem-stub::width',
    'stem-tremolo::calc-tab-width',
    'stem::calc-duration-log',
    'stem::kievan-offset-callback',
    'stencil-true-extent',
    'stencil-whiteout',
    'stencil-whiteout-box',
    'stencil-whiteout-outline',
    'stencil-with-color',
    'straight-flag',
    'string-encode-integer',
    'string-endswith',
    'string-number::calc-text',
    'string-or-music?',
    'string-or-pair?',
    'string-or-symbol?',
    'string-regexp-substitute',
    'string-startswith',
    'stroke-finger::calc-text',
    'style-note-heads',
    'suggest-convert-ly-message',
    'symbol-concatenate',
    'symbol-footnotes',
    'symbol-key-alist?',
    'symbol-list-or-music?',
    'symbol-list-or-symbol?',
    'symbol-list?',
    'symlink-if-not-exist',
    'symlink-or-copy-if-not-exist',
    'symmetric-interval',
    'system-clipped-x-extent',
    'system-start-text::calc-x-offset',
    'system-start-text::calc-y-offset',
    'system-start-text::print',
    'tab-note-head::calc-glyph-name',
    'tab-note-head::print',
    'tab-note-head::whiteout-if-style-set',
    'tablature-position-on-lines',
    'tabvoice::draw-double-stem-for-half-notes',
    'tabvoice::make-double-stem-width-for-half-notes',
    'tag-group-get',
    'tags-keep-predicate',
    'tags-remove-predicate',
    'teaching-accidental-rule',
    'tempo',
    'text-mark-interface::calc-break-visibility',
    'text-mark-interface::calc-self-alignment-X',
    'tie::handle-tab-note-head',
    'trill-pitch-group::pure-height',
    'tuplet-number::calc-denominator-text',
    'tuplet-number::calc-direction',
    'tuplet-number::calc-fraction-text',
    'type-name',
    'unbroken-or-first-broken-spanner?',
    'unbroken-or-last-broken-spanner?',
    'unbroken-spanner?',
    'unfold-repeats',
    'unfold-repeats-fully',
    'uniq-list',
    'uniqued-alist',
    'unity-if-multimeasure',
    'unrelativable-music',
    'value->lily-string',
    'value-for-spanner-piece',
    'vector-for-each',
    'version-not-seen-message',
    'voicify-music',
    'void-music',
    'void?',
    'volta-bracket-interface::pure-height',
    'volta-bracket::calc-hook-visibility',
    'volta-spec-music',
    'warning',
    'with-music-match',
    'write-me',
    'write-performances-midis',
]

scheme_variables = [
    'accidental-interface::height',
    'all-backend-properties',
    'all-internal-grob-properties',
    'all-internal-translation-properties',
    'all-invisible',
    'all-music-font-encodings',
    'all-music-properties',
    'all-text-font-encodings',
    'all-translation-properties',
    'all-user-grob-properties',
    'all-user-translation-properties',
    'all-visible',
    'alteration-default-glyph-name-alist',
    'alteration-hufnagel-glyph-name-alist',
    'alteration-kievan-glyph-name-alist',
    'alteration-medicaea-glyph-name-alist',
    'alteration-mensural-glyph-name-alist',
    'alteration-vaticana-glyph-name-alist',
    'assoc-get',
    'axis-group-interface::height',
    'balloon::height',
    'begin-of-line-invisible',
    'begin-of-line-visible',
    'black',
    'blue',
    'brace-encoding-table',
    'car<',
    'center-invisible',
    'center-visible',
    'chain-assoc-get',
    'constante-hairpin',
    'create-script-function',
    'css-color',
    'current-outfile-name',
    'cyan',
    'darkblue',
    'darkcyan',
    'darkgreen',
    'darkmagenta',
    'darkred',
    'darkyellow',
    'debug-gc-object-lifetimes-test-object',
    'default-breath-alist',
    'default-chord-modifier-list',
    'default-measure-division-chord-placement-alist',
    'default-measure-division-lines-alist',
    'default-melisma-properties',
    'default-part-combine-context-change-state-machine-one',
    'default-part-combine-context-change-state-machine-two',
    'default-part-combine-mark-state-machine',
    'default-script-alist',
    'default-slur-details',
    'default-time-signature-settings',
    'dimension-arrows',
    'documented-paper-alist',
    'dynamic-default-volume',
    'empty-interval',
    'empty-markup',
    'empty-stencil',
    'end-of-line-invisible',
    'end-of-line-visible',
    'feta-design-size-mapping',
    'finger-glide::print',
    'flared-hairpin',
    'format-coda-mark',
    'format-mark-alphabet',
    'format-mark-barnumbers',
    'format-mark-box-alphabet',
    'format-mark-box-barnumbers',
    'format-mark-box-letters',
    'format-mark-box-numbers',
    'format-mark-circle-alphabet',
    'format-mark-circle-barnumbers',
    'format-mark-circle-letters',
    'format-mark-circle-numbers',
    'format-mark-letters',
    'format-mark-numbers',
    'format-segno-mark',
    'format-varcoda-mark',
    'glyph-encoding-table',
    'green',
    'grey',
    'grid-chord-name::calc-X-offset',
    'grid-chord-name::calc-Y-offset',
    'grob::always-Y-extent-from-stencil',
    'grob::always-horizontal-skylines-from-element-stencils',
    'grob::always-horizontal-skylines-from-stencil',
    'grob::always-vertical-skylines-from-element-stencils',
    'grob::always-vertical-skylines-from-stencil',
    'grob::unpure-horizontal-skylines-from-stencil',
    'grob::unpure-vertical-skylines-from-stencil',
    'guile-predicates',
    'instrument-names-alist',
    'interpret-markup',
    'interval-end',
    'interval-start',
    'lily-unit->bigpoint-factor',
    'lily-unit->mm-factor',
    'lilypond-exported-predicates',
    'lilypond-scheme-predicates',
    'magenta',
    'makam-alteration-glyph-name-alist',
    'markup-command-signature',
    'markup-function-as-string-method',
    'markup-function-category',
    'markup-function-properties',
    'markup-list-function?',
    'markup?',
    'median-measure-division-chord-placement-alist',
    'median-measure-division-lines-alist',
    'music-descriptions',
    'music-name-to-property-table',
    'ottavation-numbers',
    'ottavation-ordinals',
    'ottavation-simple-ordinals',
    'page-property',
    'paper-alist',
    'paper-variable',
    'point-stencil',
    'property-override',
    'property-set',
    'pure-from-neighbor-interface::height-if-pure',
    'red',
    'repeat',
    'rhythmic-location-bar-number',
    'rhythmic-location-measure-position',
    'score-grace-settings',
    'self-alignment-interface::y-aligned-on-self',
    'set-symbol',
    'side-position-interface::y-aligned-side',
    'slur::height',
    'slur::move-closer-to-tab-note-heads',
    'staff-symbol-referencer::callback',
    'standard-alteration-glyph-name-alist',
    'stencil-dispatch-alist',
    'supported-clefs',
    'symbol-key<?',
    'symbol<?',
    'type-predicates-doc-string',
    'universal-color',
    'white',
    'woodwind-instrument-list',
    'yellow',
]

scheme_constants = [
    'CENTER',
    'DOUBLE-FLAT',
    'DOUBLE-SHARP',
    'DOWN',
    'FIVE-HALF-FLAT',
    'FIVE-HALF-SHARP',
    'FLAT',
    'INF-MOMENT',
    'INFINITY-INT',
    'LEFT',
    'NATURAL',
    'PI',
    'PI-OVER-TWO',
    'PLATFORM',
    'RIGHT',
    'SEMI-FLAT',
    'SEMI-SHARP',
    'SEMI-TONE',
    'SEVEN-HALF-FLAT',
    'SEVEN-HALF-SHARP',
    'SHARP',
    'START',
    'STOP',
    'THREE-PI-OVER-TWO',
    'THREE-Q-FLAT',
    'THREE-Q-SHARP',
    'TWO-PI',
    'UP',
    'X',
    'Y',
    'ZERO-DURATION',
    'ZERO-MOMENT',
]




# This file is part of python-ly, https://pypi.python.org/pypi/python-ly
#
# Copyright (c) 2008 - 2015 by Wilbert Berendsen
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
# See http://www.gnu.org/licenses/ for more information.

"""
Formatting tools to improve the readability of a ly.document.Document without
changing the semantic meaning of the LilyPond source.

Basically the tools only change whitespace to make the source-code more 
readable.

See also ly.indent.

"""

from __future__ import unicode_literals

import ly.indent
import ly.lex


def break_indenters(cursor):
    """Add newlines around indent and dedent tokens where needed.
    
    If there is stuff after a { or << (that's not closed on the same line) 
    it is put on a new line, and if there if stuff before a } or >>, the } 
    or >> is put on a new line.
    
    It is necessary to run the indenter again over the same part of the 
    document, as it will look garbled with the added newlines.
    
    """
    with cursor.document as d:
        for b in cursor.blocks():
            denters = []
            tokens = d.tokens(b)
            nonspace_index = -1
            for i, t in enumerate(tokens):
                if isinstance(t, ly.lex.Indent) and t in ('{', '<<'):
                    denters.append(i)
                elif isinstance(t, ly.lex.Dedent) and t in ('}', '>>'):
                    if denters:
                        denters.pop()
                    elif nonspace_index != -1:
                        # add newline before t
                        pos = d.position(b) + t.pos
                        d[pos:pos] = '\n'
                if not isinstance(t, ly.lex.Space):
                    nonspace_index = i
            for i in denters:
                if i < nonspace_index:
                    # add newline after tokens[i]
                    pos = d.position(b) + tokens[i].end
                    d[pos:pos] = '\n'


def move_long_comments(cursor):
    """Move line comments with more than 2 comment characters to column 0."""
    with cursor.document as d:
        for b in cursor.blocks():
            tokens = d.tokens(b)
            if (len(tokens) == 2
                and isinstance(tokens[0], ly.lex.Space)
                and isinstance(tokens[1], (
                    ly.lex.lilypond.LineComment,
                    ly.lex.scheme.LineComment))
                and tokens[1][:3] in ('%%%', ';;;')):
                del d[d.position(b):d.position(b) + tokens[1].pos]


def remove_trailing_whitespace(cursor):
    """Removes whitespace from all lines in the cursor's range."""
    with cursor.document as d:
        for b in cursor.blocks():
            tokens = d.tokens(b)
            if tokens:
                t = tokens[-1]
                end = d.position(b) + t.end
                if isinstance(t, ly.lex.Space):
                    del d[end-len(t):end]
                elif not isinstance(t, ly.lex.String):
                    offset = len(t) - len(t.rstrip())
                    if offset:
                        del d[end-offset:end]


def reformat(cursor, indenter):
    """A do-it-all function improving the LilyPond source formatting."""
    break_indenters(cursor)
    indenter.indent(cursor)
    move_long_comments(cursor)
    remove_trailing_whitespace(cursor)



